<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Controllers;

use Controllers\Zones;
use Domframework\Authzgroups;
use Models\Configuration;
use Models\Record;
use Models\Userpref;
use Models\Zone;

/** Do the install process :
    - Create the configuration by default
    - Create the database
    - Check the connectivity with DNS servers */
class Install
{
    /** Check the consistency of data/configuration.php. Create it if it doesn't
        exists with the default values */
    public function defaultconf()
    {
        $configuration = new Configuration();
        $servers = $configuration->get("servers");
        if (array_key_exists("not configured", $servers)) {
            // There is no configuration : write the default config
            $val = reset($servers);
            return $configuration->set("servers", $val);
        }
    }

    /** Create the tables in the database when the configuration is done */
    public function createDB()
    {
        $configuration = new Configuration();
        $dbconfig = $configuration->get("database");
        if ($dbconfig["dsn"] === null) {
            throw new \Exception(
                _("The database DSN parameter must be configured"),
                500
            );
        }
        $tableprefix = "";
        if (isset($dbconfig["tableprefix"])) {
            $tableprefix = $dbconfig["tableprefix"];
        }
        $models = array("zone", "record", "userpref");
        foreach ($models as $model) {
            $model = "Models\\" . ucfirst($model);
            $n = new $model(
                $dbconfig["dsn"],
                $dbconfig["username"],
                $dbconfig["password"],
                $dbconfig["driver_options"]
            );
            $n->tableprefix = $tableprefix;
            try {
                $n->createTable();
            } catch (\Exception $e) {
                echo $e->getMessage() . "\n";
            }
            unset($n);
        }

        $n = new Authzgroups();
        $n->connect(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $n->tableprefix = $tableprefix;
        $n->createTables();
        $n->objectAdd("domdns", "/", _("Access to zone list"));
        return true;
    }

    /** Update the database tables structure and the current content */
    public function updateDB()
    {
        // TODO : Update the tables structure when dblayer support it
        // Update the current content of the tables :
        // - Adding the existing zones in the 'object' authzgroup table
        $configuration = new Configuration();
        $dbconfig = $configuration->get("database");
        if ($dbconfig["dsn"] === null) {
            throw new \Exception(
                _("The database DSN parameter must be configured"),
                500
            );
        }
        $tableprefix = "";
        if (isset($dbconfig["tableprefix"])) {
            $tableprefix = $dbconfig["tableprefix"];
        }
        $n = new Authzgroups();
        $n->connect(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $n->tableprefix = $tableprefix;
        $objs = $n->objectRead("domdns");
        $objects = array();
        foreach ($objs as $obj) {
            $objects[] = $obj["object"];
        }

        $z = new Zone(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $z->tableprefix = $tableprefix;
        $zons = $z->read();
        $zones = array();
        $zones[] = "/";
        foreach ($zons as $zon) {
            $zones[] = "/" . $zon["zone"] . "/" . $zon["viewname"];
        }
        $diffs = array_diff($zones, $objects);

        foreach ($diffs as $diff) {
            echo "Adding object '$diff' to object database for authorization\n";
            $n->objectAdd("domdns", $diff);
        }

        echo "If there is an error, look at docs/DBUpdate file\n";
        return true;
    }

    // TODO : Check the connectivity with DNS servers with doing a reload
}
