<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Models;

 /** Servers must be configured like :
     "192.168.56.110" => array (
          "type"=>"bind",                // DNS server type (bind only actually)
          "methodCLI"=>"ssh",            // can be ssh or sudo
          "methodFILE"=>"scp",           // can be scp or sudo
          "username"=>"root",            // used to connect by SSH
          "password"=>"l1d3sq6c",        // used to connect by SSH
          "sshPort"=>22,                 // used to connect by SSH
          "fingerprint"=>FALSE,          // used to connect by SSH
          "publickeyfile"=>FALSE,        // used to connect by SSH
          "privatekeyfile"=>FALSE,       // used to connect by SSH
          "passphrase"=>FALSE,           // used to connect by SSH
          "zonepath"=>"/etc/bind/zones", // The path of the zones in bind directory
          "zonepathSSHorSUDO"=>"/etc/bind/zones", // The path of the zones in SSH or SUDO
          "rndcPath"=>"/usr/sbin/rndc",  // In "sudo" mode, by default "sudo -n -u <USERNAME> /usr/sbin/rndc"
          "serverViewSupport"=>true,     // This server supports views
      ),
      Database must be configured like PDO :
        "dsn"=>"sqlite:./data/database.db",
        "username" => null,
        "password" => null,
        "driver_options" => null,

  */

use Domframework\Config;

/** The class need to take care of configuration parameters */
class Configuration extends Config
{
    /** All the default parameters in the configuration */
    public function __construct()
    {
        $this->default = array(
        /** @param timezone
            @description The timezone used by the date function
            @type string
            @values timezone_identifiers_list
            @default "UTC" */
        "timezone" => "UTC",
        /** @param viewSupport
            @description Activate the view support in the DNS
            @type boolean
            @default true */
        "viewSupport" => true,
        /** @group DNS servers */
        "servers" => array(
        /** @param name
            @description The server name
            @type string
            @default "not configured"
            @prefix "servers" */
        "not configured" => array(
          /** @param type
              @description The DNS server software used
              @values array("bind")
              @type string
              @prefix "servers/not configured" */
          "type" => "bind",
          /** @param methodCLI
              @description The method used to reload the DNS server
              @values array("ssh","sudo")
              @type string
              @prefix "servers/not configured" */
          "methodCLI" => "ssh",     // can be ssh or sudo
          /** @param methodFILE
              @description The method used to modify the data file on
                           the server
              @values array("scp","sudo")
              @type string
              @prefix "servers/not configured" */
          "methodFILE" => "scp",    // can be scp or sudo
          /** @param username
              @description The username used to connect to the SCP
                           server.
                           Leave it blank if not used
              @type string
              @prefix "servers/not configured" */
          "username" => "",         // Used to connect to the server
          /** @param password
              @description The password used to connect to the SCP
                           server.
                           Leave it blank if not used
              @type password
              @prefix "servers/not configured" */
          "password" => "",         // Used to connect to the server
          /** @param sshPort
              @description The SSH port to be used to drive the server
              @type integer
              @default 22
              @prefix "servers/not configured" */
          "sshPort" => 22,
          /** @param fingerprint
              @description The fingerprint used to verify the SCP
                           server.
                           Leave it blank if not used
              @type string
              @prefix "servers/not configured" */
          "fingerprint" => false,   // Used on SSH/SCP to check the server
          /** @param publickeyfile
              @description The public key used to connect to the SCP
                           server.
                           Leave it blank if not used
              @type string
              @prefix "servers/not configured" */
          "publickeyfile" => false,
          /** @param privatekeyfile
              @description The private key used to connect to the SCP
                           server.
                           Leave it blank if not used
              @type string
              @prefix "servers/not configured" */
          "privatekeyfile" => false,
          /** @param passphrase
              @description The passphrase used to open the key files for
                           the SCP server.
                           Leave it blank if not used
              @type string
              @prefix "servers/not configured" */
          "passphrase" => false,
          /** @param zonepath
              @description The folder where the zones files will be
                           stored
              @type string
              @prefix "servers/not configured" */
          "zonepath" => "/etc/bind/zones",
          /** @param serverViewSupport
              @description The server is in view mode if true (then the reload
                           provide the client name), or is in global mode (the
                           reload only provide the zone name).
                           If null, use the viewSupport value
              @values array (true=>"true", false=>"false", null=>"null")
              @type boolean
              @default null */
          "serverViewSupport" => null,
        ),
        ),
      /** @group Database */
        "database" => array(
        /** @param dsn
            @description The DSN used to connect to the database.
            See <http://fr2.php.net/manual/en/pdo.construct.php#refsect1-pdo.construct-parameters> to details
            @type string
            @prefix "database" */
        "dsn" => null,
        /** @param username
            @description The username used to connect to the database.
                         Leave it blank if not used
            @type string
            @prefix "database" */
        "username" => null,
        /** @param password
            @description The password used to connect to the database.
                         Leave it blank if not used
            @type password
            @prefix "database" */
        "password" => null,
        /** @param driver_options
            @description The specific driver options used to connect to the
                         database.
                         Leave it blank if not used
            @type string
            @prefix "database" */
        "driver_options" => null,
        /** @param tableprefix
            @description The prefix added to all the table names.
                         Leave it blank if not used
            @type string
            @prefix "database" */
        "tableprefix" => "",
        ),
      /** @group DNS Zone */
        "zone" => array(
        /** @param soa-server
            @description The default DNS server written in the SOA record
            @type string
            @prefix "zone" */
        "soa-server" => null,
        /** @param soa-email
            @description The default DNS contact email written in the SOA
                         record, without @ (replaced by a dot)
            @type string
            @prefix "zone" */
        "soa-email" => null,
        /** @param soa-refresh
            @description The default refresh time in the SOA
            @default 3600
            @type integer
            @prefix "zone" */
        "soa-refresh" => 3600,
        /** @param soa-retry
            @description The default retry time in the SOA
            @default 900
            @type integer
            @prefix "zone" */
        "soa-retry" => 900,
        /** @param soa-expire
            @description The default expire time in the SOA
            @default 604800
            @type integer
            @prefix "zone" */
        "soa-expire" => 604800,
        /** @param soa-minttl
            @description The default minttl time in the SOA
            @default 3600
            @type integer
            @prefix "zone" */
        "soa-minttl" => 3600,
        ),
      /** @group Authentication */
        "authentication" => array(
        /** @param rest
            @description The authentication methods for the REST access
            @values array ("http","session","post")
            @default array ("http","session")
            @type array
            @prefix "authentication" */
        "rest" => array("http","session"),    // can be http, session, post
        /** @param html
            @description The authentication methods for the HTML access
            @values array ("http","session","post")
            @default array ("session")
            @type array
            @prefix "authentication" */
        "html" => array("session"), // can be http, session, post
        /** @param methods
            @description The authentication methods to authenticate the user
            @values array ("ldap","sympa","sql","session")
            @type array
            @prefix "authentication" */
        "methods" => array(), // can be ldap,sympa...
        /** @group Authentication LDAP */
        "authldap" => array(
          /** @param ldapserver
              @description The LDAP server name or IP. Start by "ldaps://" to
                           use the LDAPS protocol. In this case, the name must
                           be the same as the certificate of the server
              @default "localhost"
              @type string
              @prefix "authentication/authldap" */
          "ldapserver" => "localhost",
          /** @param ldapport
              @description The LDAP port (389 by default, 636 for LDAPS)
              @default 389
              @type integer
              @prefix "authentication/authldap" */
          "ldapport" => 389,
          /** @param ldaptimeout
              @description The LDAP timeout
              @default 5
              @type integer
              @prefix "authentication/authldap" */
          "ldaptimeout" => 5,
          /** @param ldapauth
              @description The LDAP pre-authentication DN
              @type string
              @prefix "authentication/authldap" */
          "ldapauth" => "",
          /** @param ldappwd
              @description The LDAP pre-authentication password
              @type password
              @prefix "authentication/authldap" */
          "ldappwd" => "",
          /** @param ldapbase
              @description The LDAP base
              @default ""
              @type string
              @prefix "authentication/authldap" */
          "ldapbase" => "",
          /** @param ldapfilter
              @description The LDAP filter. %s is replaced by the email
                           provided by the user
              @default "(mail=%s)"
              @type string
              @prefix "authentication/authldap" */
          "ldapfilter" => "(mail=%s)",
          /** @param ldapfield
              @description The LDAP field to return, containing the data
                           of the user
              @default "mail"
              @type string
              @prefix "authentication/authldap" */
          "ldapfield" => "mail",
          /** @param ldapfiltersearch
              @description The LDAP filter.
              @default "(objectClass=inetOrgPerson)"
              @type string
              @prefix "authentication/authldap" */
          "ldapfiltersearch" => "(objectClass=inetOrgPerson)"
        ),
        ),
      /** @group Authorization */
        "authorization" => array(
        /** @param administrators
            @description The emails of the administrators, separated by
                  pipes
            @type string
            @prefix "authorization" */
        "administrators" => "",
        /** @param defaultGroup
            @description The default group when creating a new zone.
                         Must already exists
            @type string
            @prefix "authorization" */
        "defaultGroup" => "",
        ),
      /** @group Logging */
        "logging" => array(
        /** @param logtype
            @description The logs systems to use
            @values array ("syslog","file")
            @type array
            @prefix "logging" */
        "logtype" => "syslog",
        /** @param logfile
            @description The logfile to use when logging by file
            @type string
            @prefix "logging" */
        "logfile" => "",
        /** @param timezone
            @description The timezone to use to store the logs
            @values timezone_identifiers_list
            @default "UTC"
            @type string
            @prefix "logging" */
        "timezone" => "UTC",
        /** @param loglevelmin
            @description The minimum log level
            @values array ("LOG_EMERG","LOG_ALERT","LOG_CRIT","LOG_ERR",
                           "LOG_WARNING","LOG_NOTICE","LOG_INFO",
                           "LOG_DEBUG")
            @default "LOG_NOTICE"
            @type string
            @prefix "logging" */
        "loglevelmin" => "LOG_NOTICE",
        /** @param syslogFacility
            @description The facility to use in syslog mode
            @values array ("LOG_AUTH", "LOG_AUTHPRIV", "LOG_DAEMON",
                           "LOG_KERN", "LOG_LOCAL0", "LOG_LOCAL1",
                           "LOG_LOCAL2", "LOG_LOCAL3", "LOG_LOCAL4",
                           "LOG_LOCAL5", "LOG_LOCAL6", "LOG_LOCAL7",
                           "LOG_LPR", "LOG_MAIL", "LOG_NEWS",
                           "LOG_SYSLOG", "LOG_USER", "LOG_UUCP")
            @default "LOG_USER"
            @type string
            @prefix "logging" */
        "syslogFacility" => "LOG_USER",
        /** @param syslogPrefix
            @description The prefix to store in the syslog
            @type string
            @prefix "logging" */
        "syslogPrefix" => false,
        ),
      /** The path where cron save the temporary data */
        "cronPath" => "data/cron",
        );

        if (defined("CONFIGFILE")) {
            $this->confFile = CONFIGFILE;
        }
    }
}
