<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Modules\Authorization\Views;

use Domframework\Csrf;
use Domframework\Form;
use Domframework\Formfield;
use Views\Confirm;
use Views\Flash;

/** Display the group members */
class GroupMembers
{
    public function readUsers($data)
    {
        // List the users of a group
        // Can display the flash
        $dataflash = Flash::call();
        $content = $dataflash;

        // The HTML code to confirm the removal of entry
        $content .= Confirm::call();
        $idgroup = $data["groups"][0]["idgroup"];
        $group = $data["groups"][0]["group"];

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}authorization'>" .
                _("Authorization") .
                "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group'>" .
                _("Groups") .
                "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group/" .
                "$idgroup'>";
        $content .= $group . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group/" .
                "$idgroup/user'>";
        $content .= _("Users") . "</a></li>\n";
        $content .= "</ol>\n";

        // Menu buttons
        $content .= "<div class='btn-group btn-sm'>\n";
        $content .= "  <a id='add' class='btn btn-default' ";
        $content .= "href='{baseurlresource}authorization/group/$idgroup/user/add'";
        $content .= ">";
        $content .= _("Add") . "</a>\n";
        $content .= "  <button id='modify' type='button' ";
        $content .= "class='disabled btn btn-default'>";
        $content .= _("Modify") . "</button>\n";
        $content .= "  <button id='delete' type='button' ";
        $content .= "class='disabled btn btn-default'>";
        $content .= _("Delete") . "</button>\n";
        $content .= "</div>\n";

        $content .= "<div class='btn-group btn-sm'>\n";
        $content .= "  <a id='add' class='btn btn-default' ";
        $content .= "href='{baseurlresource}authorization/group'>";
        $content .= _("Groups") . "</a>\n";
        $content .= "  <a id='add' class='btn btn-default' ";
        $content .= "href='{baseurlresource}authorization/object'>";
        $content .= _("Objects") . "</a>\n";
        $content .= "</div>\n";

        $content .= "<div class='table-responsive'>\n";
        if (count($data["users"]) === 0) {
            $content .= "  " . _("No record found") . "\n";
            $content .= "</div>\n";
            return array("content" => $content,
                    "title" => _("Group management : users in group $group"));
        }

        $content .= "  <table id='data' class='table table-striped'>\n";
        // Titles
        $titles = $data["titles"];
        $content .= "    <thead><tr>";
        foreach ($titles as $title) {
            if ($title === "id") {
                continue;
            }
            if ($title === "idgroup") {
                continue;
            }
            $content .= "<th>$title</th>";
        }
        $content .= "</tr></thead>\n";

        // Data
        $content .= "    <tbody>\n";
        foreach ($data["users"] as $key => $vals) {
            $content .= "      <tr>";
            /*      $content .= "      <tr onclick='location=\"";
                  $content .= $vals["zone"]."/".$vals["viewname"];
                  $content .= "\"'>";*/
            foreach ($vals as $key => $val) {
                if ($key === "id") {
                    continue;
                }
                if ($key === "idgroup") {
                    continue;
                }
                $content .= "<td>" . $val . "</td>";
            }
            $content .= "</tr>\n";
        }

        $content .= "    </tbody>\n";
        $content .= "  </table>\n";
        $content .= "</div>\n";
        $content .= "<script>baseurl='{baseurl}';" .
                "baseurlresource='{baseurlresource}';\n";
        $csrf = new Csrf();
        $content .= "csrfToken='" . $csrf->createToken() . "';";
        $content .= "</script>\n";

        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "jquery.dataTables.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/jquery.dataTables.min.js") .
                "'>";
        $content .= "</script>\n";
        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "dataTables.bootstrap.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/" .
                           "dataTables.bootstrap.min.js") .
                "'>";
        $content .= "</script>\n";
        $content .= "<script>pageurl='{baseurlresource}authorization/group/" .
                "$idgroup/user'</script>\n";
        $content .= "<script>modulerest='{baseurlresource}authorization/rest/" .
                "group'</script>\n";
        $content .= "<script src='{baseurl}Modules/Authorization/public/";
        $content .= "selectDelete.js?t=" .
                filemtime("Modules/Authorization/public/selectDelete.js") .
                "'>";
        $content .= "</script>\n";
        $content .= "<script>\n";
        $content .= "  $(document).ready(function() {\n";
        $content .= "    table = $('#data').DataTable({\n";
        $content .= "        stateSave:true,\n";
        $content .= "        stateDuration: 60*60*24*30,\n";
        if (isset($GLOBALS["domframework"]["lang"])) {
            $content .= "        language: {
                    url:'{baseurl}public/DataTables-1.10.12/js/" .
                    $GLOBALS["domframework"]["lang"] . ".json'
                  }\n";
        }
        $content .= "    });\n";
        $content .= "    $('#data_wrapper').css('cursor', 'default');\n";
        $content .= "  });\n";
        $content .= "</script>\n";

        return array("content" => $content,
                  "title" => _("Group management : users in group $group"));
    }

    public function updateUsers($data)
    {
        // Can display the flash
        $dataflash = Flash::call();
        $content = $dataflash;

        $idgroup = $data["groups"][0]["idgroup"];
        $group = $data["groups"][0]["group"];

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}authorization'>" .
                _("Authorization") .
                "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group'>" .
                _("Groups") .
                "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group/" .
                "$idgroup'>";
        $content .= $group . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group/" .
                "$idgroup/user'>";
        $content .= _("Users") . "</a></li>\n";
        $content .= "</ol>\n";

        // Menu buttons
        $content .= "<div class='btn-group btn-sm'>\n";
        $content .= "<button id='edit' class='btn btn-default' ";
        $content .= "onclick='\$(\"#form\").find(\"*\").show();";
        $content .= "\$(\"#form\").find(\"*\").removeAttr(\"readonly\")'>";
        $content .= _("Edit User") . "</button>\n";
        $content .= "</div>\n";

        $edit = false;
        if (isset($data["values"][0]["idgroupmember"])) {
            $edit = true;
        }

        if (isset($_SESSION["authorization"]["values"])) {
            $values = $_SESSION["authorization"]["values"];
            unset($_SESSION["authorization"]["values"]);
        } elseif (isset($data["values"][0])) {
            $values = $data["values"][0];
        } else {
            $values = array();
        }
        if (isset($_SESSION["authorization"]["errors"])) {
            $errors = $_SESSION["authorization"]["errors"];
            unset($_SESSION["authorization"]["errors"]);
        } else {
            $errors = array();
        }
        $f = new Form();
        $fields = array();

        $field = new Formfield("module", "module");
        $field->type = "hidden";
        $field->defaults = "domdns";
        $fields[] = $field;
        unset($field);

        $field = new Formfield("idgroup", "idgroup");
        $field->type = "hidden";
        $field->defaults = $idgroup;
        $fields[] = $field;
        unset($field);

        $field = new Formfield("user", _("User"));
        $field->type = "text";
        $field->mandatory = true;
        //if ($edit)
        //  $field->readonly = true;
        $fields[] = $field;

        $field = new Formfield("comment", _("Comment"));
        $field->type = "text";
        //if ($edit)
        //  $field->readonly = true;
        $fields[] = $field;

        $field = new Formfield("submit", _("Send the request"));
        $field->type = "submit";
        if ($edit) {
            $field->hidden = true;
        }
        $fields[] = $field;

        $f->fields($fields);


        $content .= $f->printHTML("post", $values, $errors);
        // Display the groups where the user is on
        $content .= "<h2>" . _("Members of group:") . "</h2>\n";
        if (count($data["members"]) === 0) {
            $content .= _("No group linked to this user");
        } else {
            $content .= "<ul>\n";
            foreach ($data["members"] as $group) {
                $content .= "<li>". $group["user"] ."</li>\n";
            }
            $content .= "</ul>\n";
        }
        return array("content" => $content,
                  "title" => _("Add a new group for authorizations"));
    }
}
