<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Modules\Authorization\Views;

use Domframework\Csrf;
use Domframework\Form;
use Domframework\Formfield;
use Views\Confirm;
use Views\Flash;

/** Display the rights for a group or an object */
class Rights
{
    // GROUP
    public function readGroup($data)
    {
        // List the rights of a group
        // Can display the flash
        $dataflash = Flash::call();
        $content = $dataflash;

        // The HTML code to confirm the removal of entry
        $content .= Confirm::call();
        $idgroup = $data["idgroup"];
        $group = $data["group"];

        $groupNames = array();
        foreach ($data["groupNames"] as $val) {
            $groupNames[$val["idgroup"]] = $val["group"];
        }
        $objectNames = array();
        foreach ($data["objectNames"] as $val) {
            $objectNames[$val["idobject"]] = $val["object"];
        }
        $rightTypes = $data["rightTypes"];

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}authorization'>" .
                _("Authorization") . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group'>" .
                _("Groups") . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group/" .
                "$idgroup'>";
        $content .= $group . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group/" .
                "$idgroup/right'>";
        $content .= _("Rights") . "</a></li>\n";
        $content .= "</ol>\n";

        // Menu buttons
        $content .= "<div class='btn-group btn-sm'>\n";
        $content .= "  <a id='add' class='btn btn-default' ";
        $content .= "href='{baseurlresource}authorization/group/$idgroup" .
                "/right/add'";
        $content .= ">";
        $content .= _("Add") . "</a>\n";
        $content .= "  <button id='modify' type='button' ";
        $content .= "class='disabled btn btn-default'>";
        $content .= _("Modify") . "</button>\n";
        $content .= "  <button id='delete' type='button' ";
        $content .= "class='disabled btn btn-default'>";
        $content .= _("Delete") . "</button>\n";
        $content .= "</div>\n";

        $content .= "<div class='table-responsive'>\n";
        if (count($data["rights"]) === 0) {
            $content .= "  " . _("No record found") . "\n";
            $content .= "</div>\n";
            return array("content" => $content,
                    "title" => _("Group management : rights in group $group"));
        }

        $content .= "  <table id='data' class='table table-striped'>\n";
        // Titles
        $titles = $data["titles"];
        $content .= "    <thead><tr>";
        foreach ($titles as $title) {
            if ($title === "idgroup") {
                continue;
            }
            if ($title === "idobject") {
                $content .= "<th>" . _("Object") . "</th>";
            } else {
                $content .= "<th>$title</th>";
            }
        }
        $content .= "</tr></thead>\n";

        // Data
        $content .= "    <tbody>\n";
        foreach ($data["rights"] as $key => $vals) {
            $content .= "      <tr>";
            /*      $content .= "      <tr onclick='location=\"";
                  $content .= $vals["zone"]."/".$vals["viewname"];
                  $content .= "\"'>";*/
            foreach ($vals as $key => $val) {
                if ($key === "idgroup") {
                    continue;
                }
                switch ($key) {
                    case "idgroup":
                        $val = $groupNames[$val];
                        break;
                    case "idobject":
                //      $content .= "<td>".$val."</td>";
                        $val = $objectNames[$val];
                        break;
                    case "right":
                        $val = $rightTypes[$val];
                        break;
                }
                $content .= "<td>" . $val . "</td>";
            }
            $content .= "</tr>\n";
        }

        $content .= "    </tbody>\n";
        $content .= "  </table>\n";
        $content .= "</div>\n";
        $content .= "<script>baseurl='{baseurl}';" .
                "baseurlresource='{baseurlresource}';\n";
        $csrf = new Csrf();
        $content .= "csrfToken='" . $csrf->createToken() . "';";
        $content .= "</script>\n";

        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "jquery.dataTables.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/jquery.dataTables.min.js") .
                "'>";
        $content .= "</script>\n";
        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "dataTables.bootstrap.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/" .
                           "dataTables.bootstrap.min.js") .
                "'>";
        $content .= "</script>\n";
        $content .= "<script>pageurl='{baseurlresource}authorization/group/" .
                "$idgroup/right'</script>\n";
        $content .= "<script>modulerest='{baseurlresource}authorization/rest/" .
                "group'</script>\n";
        $content .= "<script src='{baseurl}Modules/Authorization/public/";
        $content .= "selectDelete.js?t=" .
                filemtime("Modules/Authorization/public/selectDelete.js") . "'>";
        $content .= "</script>\n";
        $content .= "<script>\n";
        $content .= "  $(document).ready(function() {\n";
        $content .= "    table = $('#data').DataTable({\n";
        $content .= "        stateSave:true,\n";
        $content .= "        stateDuration: 60*60*24*30,\n";
        if (isset($GLOBALS["domframework"]["lang"])) {
            $content .= "        language: {
                    url:'{baseurl}public/DataTables-1.10.12/js/" .
                    $GLOBALS["domframework"]["lang"] . ".json'
                  }\n";
        }
        $content .= "    });\n";
        $content .= "    $('#data_wrapper').css('cursor', 'default');\n";
        $content .= "  });\n";
        $content .= "</script>\n";

        return array("content" => $content,
                  "title" => _("Group management : rights in group $group"));
    }

    public function updateGroup($data)
    {
        $dataflash = Flash::call();
        $content = $dataflash;

        $idgroup = $data["idgroup"];
        $group = $data["group"];

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}authorization'>" .
                _("Authorization") . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group'>" .
                _("Groups") . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group/" .
                "$idgroup'>";
        $content .= $group . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/group/" .
                "$idgroup/right'>";
        $content .= _("Rights") . "</a></li>\n";
        $content .= "</ol>\n";

        if (! isset($data["values"])) {
            $content .= "<h2>" . _("Add a new authorization for group") .
                  " : <i>$group</i></h2>\n";
        } else {
            $content .= "<h2>" . _("Edit an existing authorization for group") .
                  " : <i>$group</i></h2>\n";
        }

        $edit = false;
        if (isset($data["values"][0]["idgroupmember"])) {
            $edit = true;
        }

        if (isset($_SESSION["authorization"]["values"])) {
            $values = $_SESSION["authorization"]["values"];
            unset($_SESSION["authorization"]["values"]);
        } elseif (isset($data["values"][0])) {
            $values = $data["values"][0];
        } else {
            $values = array();
        }
        if (isset($_SESSION["authorization"]["errors"])) {
            $errors = $_SESSION["authorization"]["errors"];
            unset($_SESSION["authorization"]["errors"]);
        } else {
            $errors = array();
        }
        $f = new Form();
        $fields = array();

        $field = new Formfield("module", "module");
        $field->type = "hidden";
        $field->defaults = "domdns";
        $fields[] = $field;
        unset($field);

        $field = new Formfield("idgroup", "idgroup");
        $field->type = "hidden";
        $field->defaults = $idgroup;
        $fields[] = $field;
        unset($field);

        $field = new Formfield("idobject", _("Object"));
        $field->type = "select";
        $field->mandatory = true;
        //if ($edit)
        //  $field->readonly = true;
        $field->defaults = $data["objects"];
        $fields[] = $field;

        $field = new Formfield("right", _("Right"));
        $field->type = "select";
        $field->mandatory = true;
        //if ($edit)
        //  $field->readonly = true;
        $field->defaults = $data["rightTypes"];
        $fields[] = $field;

        $field = new Formfield("comment", _("Comment"));
        $field->type = "text";
        //if ($edit)
        //  $field->readonly = true;
        $fields[] = $field;

        $field = new Formfield("submit", _("Send the request"));
        $field->type = "submit";
        if ($edit) {
            $field->hidden = true;
        }
        $fields[] = $field;

        $f->fields($fields);


        $content .= $f->printHTML("post", $values, $errors);
        return array("content" => $content,
                  "title" => _("Add a new authorization for group $group"));
    }

    // OBJECT
    public function readObject($data)
    {
        // List the rights associated to an object
        $dataflash = Flash::call();
        $content = $dataflash;

        // The HTML code to confirm the removal of entry
        $content .= Confirm::call();
        $idobject = $data["idobject"];
        $object = $data["object"];

        $groupNames = array();
        foreach ($data["groupNames"] as $val) {
            $groupNames[$val["idgroup"]] = $val["group"];
        }
        $rightTypes = $data["rightTypes"];

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}authorization'>" .
                _("Authorization") . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/object'>" .
                _("Object") . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/object/" .
                "$idobject'>";
        $content .= $object . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/object/" .
                "$idobject/right'>";
        $content .= _("Rights") . "</a></li>\n";
        $content .= "</ol>\n";

        // Menu buttons
        $content .= "<div class='btn-group btn-sm'>\n";
        $content .= "  <a id='add' class='btn btn-default' ";
        $content .= "href='{baseurlresource}authorization/object/$idobject/right/" .
                "add'";
        $content .= ">";
        $content .= _("Add") . "</a>\n";
        $content .= "  <button id='modify' type='button' ";
        $content .= "class='disabled btn btn-default'>";
        $content .= _("Modify") . "</button>\n";
        $content .= "  <button id='delete' type='button' ";
        $content .= "class='disabled btn btn-default'>";
        $content .= _("Delete") . "</button>\n";
        $content .= "</div>\n";

        $content .= "<div class='table-responsive'>\n";
        if (count($data["rights"]) === 0) {
            $content .= "  " . _("No record found") . "\n";
            $content .= "</div>\n";
            return array("content" => $content,
                    "title" => _("Object management : rights for object $object"),
                   );
        }

        $content .= "  <table id='data' class='table table-striped'>\n";
        // Titles
        $titles = $data["titles"];
        $content .= "    <thead><tr>";
        foreach ($titles as $title) {
            if ($title === "idobject") {
                continue;
            }
            if ($title === "idgroup") {
                $content .= "<th>" . _("Group") . "</th>";
            } else {
                $content .= "<th>$title</th>";
            }
        }
        $content .= "</tr></thead>\n";

        // Data
        $content .= "    <tbody>\n";
        foreach ($data["rights"] as $key => $vals) {
            $content .= "      <tr>";
            foreach ($vals as $key => $val) {
                if ($key === "idobject") {
                    continue;
                }
                switch ($key) {
                    case "idgroup":
                        $val = $groupNames[$val];
                        break;
                    case "idobject":
                        $val = $objectNames[$val];
                        break;
                    case "right":
                        $val = $rightTypes[$val];
                        break;
                }
                $content .= "<td>" . $val . "</td>";
            }
            $content .= "</tr>\n";
        }

        $content .= "    </tbody>\n";
        $content .= "  </table>\n";
        $content .= "</div>\n";
        $content .= "<script>baseurl='{baseurl}';" .
                "baseurlresource='{baseurlresource}';\n";
        $csrf = new Csrf();
        $content .= "csrfToken='" . $csrf->createToken() . "';";
        $content .= "</script>\n";

        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "jquery.dataTables.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/jquery.dataTables.min.js") .
                "'>";
        $content .= "</script>\n";
        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "dataTables.bootstrap.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/" .
                "dataTables.bootstrap.min.js") . "'>";
        $content .= "</script>\n";
        $content .= "<script>pageurl='{baseurl}authorization/object/$idobject/" .
                "right'</script>\n";
        $content .= "<script>modulerest='{baseurl}authorization/rest/object'" .
                "</script>\n";
        $content .= "<script src='{baseurl}Modules/Authorization/public/";
        $content .= "selectDelete.js?t=" .
                filemtime("Modules/Authorization/public/selectDelete.js") . "'>";
        $content .= "</script>\n";
        $content .= "<script>\n";
        $content .= "  $(document).ready(function() {\n";
        $content .= "    table = $('#data').DataTable({\n";
        $content .= "        stateSave:true,\n";
        $content .= "        stateDuration: 60*60*24*30,\n";
        if (isset($GLOBALS["domframework"]["lang"])) {
            $content .= "        language: {
                    url:'{baseurl}public/DataTables-1.10.12/js/" .
                    $GLOBALS["domframework"]["lang"] . ".json'
                  }\n";
        }
        $content .= "    });\n";
        $content .= "    $('#data_wrapper').css('cursor', 'default');\n";
        $content .= "  });\n";
        $content .= "</script>\n";

        return array("content" => $content,
                  "title" => _("Object management : rights for object $object"));
    }

    public function updateObject($data)
    {
        $dataflash = Flash::call();
        $content = $dataflash;

        $idobject = $data["idobject"];
        $objectName = $data["objectName"];
        $groupNames = array();
        foreach ($data["groupNames"] as $val) {
            $groupNames[$val["idgroup"]] = $val["group"];
        }

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}authorization'>" .
                _("Authorization") . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/object'>" .
                _("Objects") . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/object/" .
                "$idobject'>";
        $content .= $objectName . "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}authorization/object/" .
                "$idobject/right'>";
        $content .= _("Rights") . "</a></li>\n";
        $content .= "</ol>\n";

        if (! isset($data["values"])) {
            $content .= "<h2>" . _("Add a new authorization for object") .
                  " : <i>$objectName</i></h2>\n";
        } else {
            $content .= "<h2>" . _("Edit an existing authorization for object") .
                  " : <i>$objectName</i></h2>\n";
        }

        $edit = false;
        if (isset($data["values"][0]["idgroupmember"])) {
            $edit = true;
        }

        if (isset($_SESSION["authorization"]["values"])) {
            $values = $_SESSION["authorization"]["values"];
            unset($_SESSION["authorization"]["values"]);
        } elseif (isset($data["values"][0])) {
            $values = $data["values"][0];
        } else {
            $values = array();
        }
        if (isset($_SESSION["authorization"]["errors"])) {
            $errors = $_SESSION["authorization"]["errors"];
            unset($_SESSION["authorization"]["errors"]);
        } else {
            $errors = array();
        }
        $f = new Form();
        $fields = array();

        $field = new Formfield("module", "module");
        $field->type = "hidden";
        $field->defaults = "domdns";
        $fields[] = $field;
        unset($field);

        $field = new Formfield("idobject", "idobject");
        $field->type = "hidden";
        $field->defaults = $idobject;
        $fields[] = $field;
        unset($field);

        $field = new Formfield("idgroup", _("Group"));
        $field->type = "select";
        $field->mandatory = true;
        //if ($edit)
        //  $field->readonly = true;
        $field->defaults = $groupNames;
        $fields[] = $field;

        $field = new Formfield("right", _("Right"));
        $field->type = "select";
        $field->mandatory = true;
        //if ($edit)
        //  $field->readonly = true;
        $field->defaults = $data["rightTypes"];
        $fields[] = $field;

        $field = new Formfield("comment", _("Comment"));
        $field->type = "text";
        //if ($edit)
        //  $field->readonly = true;
        $fields[] = $field;

        $field = new Formfield("submit", _("Send the request"));
        $field->type = "submit";
        if ($edit) {
            $field->hidden = true;
        }
        $fields[] = $field;

        $f->fields($fields);

        $content .= $f->printHTML("post", $values, $errors);
        if (! isset($data["values"])) {
            return array("content" => $content,
                    "title" =>
                           _("Add a new authorization for object $objectName"));
        } else {
            return array("content" => $content,
                    "title" =>
                           _("Edit an authorization for object $objectName"));
        }
    }
}
