<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

use Domframework\Csrf;
use Domframework\Form;
use Domframework\Renderer;
use Modules\Authorization\Controllers\Groups;
use Modules\Authorization\Controllers\GroupMembers;
use Modules\Authorization\Controllers\Objects;
use Modules\Authorization\Controllers\RendererAuthorization;
use Modules\Authorization\Controllers\Rights;

//   ==>   REST PART   <==
$route->errors = array("errors", "rest");

$route->get(
    "authorization/rest/group/{groupid}",
    function ($groupid) use ($authentication, $route) {
        die("TBTESTED : " . __FILE__ . ":" . __LINE__ . "\n");
        $authREST = $authentication->verifAuthREST();
        $groups = new Groups($authHTML);
        $data = $groups->read($groupid);
        //var_dump($data);
        RendererAuthorization::rest($data, 200);
    }
);

//   ==>   HTML PART   <==
$route->errors = null;
$route->authenticationURL = "/authentication/";
$route->layout = "layout";
$route->replacement = array("{baseurl}" => $route->baseURL(),
                             "{baseurlresource}" => $route->baseURLresource());
$route->viewClass = "error";
$route->viewMethod = "html";

// GROUP MEMBERS : AUTH TO BE DONE
$route->get(
    "authorization/group/{idgroup}/user",
    function ($idgroup) use ($authentication, $route) {
        // All the users in the group
        $authHTML = $authentication->verifAuthHTML();
        $group = new Groups($authHTML);
        $groups = $group->readByID($idgroup);
        if (count($groups) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }
        $groupmembers = new GroupMembers($authHTML);
        $users = $groupmembers->readgroupByID($idgroup);
        $titles = $groupmembers->titles();
        RendererAuthorization::html(
            "Modules\Authorization\Views\GroupMembers",
            "readUsers",
            array("users" => $users,
                                      "groups" => $groups,
                                      "titles" => $titles)
        );
    }
)

->get(
    "authorization/group/{idgroup}/user/add",
    function ($idgroup) use ($authentication, $route) {
        // Display the form to add a new user to idgroup
        $authHTML = $authentication->verifAuthHTML();
        $group = new Groups($authHTML);
        $groups = $group->readByID($idgroup);
        $groupmembers = new Groupmembers($authHTML);
        if (count($groups) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }
        RendererAuthorization::html(
            "Modules\Authorization\Views\GroupMembers",
            "updateUsers",
            array(
                "groups" => $groups,
                "members" => $groupmembers->readgroupByID($idgroup),
            )
        );
    }
)

->post(
    "authorization/group/{idgroup}/user/add",
    function ($idgroup) use ($authentication, $route) {
        // Save the new user in the group
        $authHTML = $authentication->verifAuthHTML();
        $group = new Groups($authHTML);
        $groups = $group->readByID($idgroup);
        if (count($groups) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }

        $renderer = new Renderer();
        $f = new Form();
        $values = $f->values();
        $groupmembers = new Groupmembers($authHTML);
        // Test the values before adding entry
        $errors = $groupmembers->verify($values);
        if (count($errors) === 0) {
            try {
                $groupmembers->add(
                    $groups[0]["group"],
                    $values["user"],
                    $values["comment"]
                );
                //$renderer->flash ("SUCCESS", _("Creation done"));
                $route->redirect("/group/$idgroup/user", "authorization");
            } catch (\Exception $e) {
                $renderer->flash("ERROR", $e->getMessage());
            }
        } else {
            $renderer = new Renderer();
            foreach ($errors as $error) {
                $renderer->flash(strtoupper($error[0]), $error[1]);
            }
        }
        unset($renderer);
        $_SESSION["authorization"]["errors"] = $errors;
        $_SESSION["authorization"]["values"] = $values;
        $route->redirect("/group/$idgroup/user/add", "authorization");
    }
)

->get(
    "authorization/group/{idgroup}/user/{idgroupmember}/delete/{token}",
    function ($idgroup, $idgroupmember, $token) use ($authentication, $route) {
        // Delete a groupmember if the CSRF token is correct
        $authHTML = $authentication->verifAuthHTML();
        $csrf = new Csrf();
        $renderer = new Renderer();
        try {
            $csrf->checkToken($token);
            $groupmembers = new Groupmembers($authHTML);
            $groupmembers->delByID($idgroup, $idgroupmember);
            $route->redirect("/group/$idgroup/user", "authorization");
        } catch (\Exception $e) {
            $renderer->flash("ERROR", $e->getMessage());
            $route->redirect("/group/$idgroup/user", "authorization");
        }
    }
)

->get(
    "authorization/group/{idgroup}/user/{idgroupmember}",
    function ($idgroup, $idgroupmember) use ($authentication, $route) {
        // Display the form to add a new user to idgroup
        $authHTML = $authentication->verifAuthHTML();
        $group = new Groups($authHTML);
        $groups = $group->readByID($idgroup);
        if (count($groups) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }
        $groupmembers = new Groupmembers($authHTML);
        $values = $groupmembers->readuserDataByID($idgroup, $idgroupmember);
        $members = $groupmembers->readuserByID($idgroupmember);
        RendererAuthorization::html(
            "Modules\Authorization\Views\GroupMembers",
            "updateUsers",
            array("groups" => $groups,
                                      "members" => $members,
                                      "values" => $values)
        );
    }
)

->post(
    "authorization/group/{idgroup}/user/{idgroupmember}",
    function ($idgroup, $idgroupmember) use ($authentication, $route) {
        // Save the new user in the group
        $authHTML = $authentication->verifAuthHTML();
        $group = new Groups($authHTML);
        $groups = $group->readByID($idgroup);
        if (count($groups) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }

        $renderer = new Renderer();
        $f = new Form();
        $values = $f->values();
        $groupmembers = new Groupmembers($authHTML);
        // Test the values before adding entry
        $errors = $groupmembers->verify($values, $idgroupmember);
        if ($values["idgroup"] !== $idgroup) {
            $errors["idgroup"] = array("ERROR",
                                _("Changing idgroup is not allowed"));
        }
        if (count($errors) === 0) {
            try {
                $cnt = $groupmembers->updateByID(
                    $idgroup,
                    $idgroupmember,
                    $values["user"],
                    $values["comment"]
                );
                //$renderer->flash ("SUCCESS", _("Modification done"));
                $route->redirect("/group/$idgroup/user", "authorization");
            } catch (\Exception $e) {
                $renderer->flash("ERROR", $e->getMessage());
            }
        } else {
            $renderer = new Renderer();
            foreach ($errors as $error) {
                $renderer->flash(strtoupper($error[0]), $error[1]);
            }
        }
        unset($renderer);
        $_SESSION["authorization"]["errors"] = $errors;
        $_SESSION["authorization"]["values"] = $values;
        $route->redirect("/group/$idgroup/user/$idgroupmember", "authorization");
    }
)

// RIGHTS ASSOCIATED TO AN OBJECT : DONE
->get(
    "authorization/object/{idobject}/right",
    function ($idobject) use ($authentication, $route) {
        // Display all the rights associated to this object
        $authHTML = $authentication->verifAuthHTML();
        $objects = new Objects($authHTML);
        $values = $objects->readByID($idobject);
        if (count($values) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Object not found"));
            $route->redirect("/object", "authorization");
        }
        $objectName = $values[0]["object"];
        $rights = new Rights($authHTML);
        $values = $rights->readByObjectByID($idobject);
        $rightTypes = $rights->types();
        $titles = $rights->titles();
        $groups = new groups($authHTML);
        $groupNames = $groups->read();
        RendererAuthorization::html(
            "Modules\Authorization\Views\Rights",
            "readObject",
            array("idobject" => $idobject,
                                      "object" => $objectName,
                                      "titles" => $titles,
                                      "rights" => $values,
                                      "groupNames" => $groupNames,
                                      "rightTypes" => $rightTypes,
                              )
        );
    }
)

/** Add a new right to an object : display the form */
->get(
    "authorization/object/{idobject}/right/add",
    function ($idobject) use ($authentication, $route) {
        $authHTML = $authentication->verifAuthHTML();
        $objects = new objects($authHTML);
        $values = $objects->readByID($idobject);
        if (count($values) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Object not found"));
            $route->redirect("/object", "authorization");
        }
        $objectName = $values[0]["object"];
        $groups = new Groups($authHTML);
        $groupNames = $groups->read();
        $rights = new Rights($authHTML);
        $rightTypes = $rights->types();
        RendererAuthorization::html(
            "Modules\Authorization\Views\Rights",
            "updateObject",
            array("idobject" => $idobject,
                                      "objectName" => $objectName,
                                      "groupNames" => $groupNames,
                                      "rightTypes" => $rightTypes,
                               )
        );
    }
)

/** Add a new right to an object : save the data */
->post(
    "authorization/object/{idobject}/right/add",
    function ($idobject) use ($authentication, $route) {
        $authHTML = $authentication->verifAuthHTML();
        $objects = new objects($authHTML);
        $object = $objects->readByID($idobject);
        if (count($object) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Object not found"));
            $route->redirect("/object", "authorization");
        }
        $renderer = new Renderer();
        $f = new form();
        $values = $f->values();
        $rights = new Rights($authHTML);
        // Test the values before adding entry
        $errors = $rights->verify($values);
        if (count($errors) === 0) {
            try {
                $rights->addByID(
                    $values["idgroup"],
                    $values["idobject"],
                    $values["right"],
                    $values["comment"]
                );
                $route->redirect("/object/$idobject/right", "authorization");
            } catch (\Exception $e) {
                $renderer->flash("ERROR", $e->getMessage());
            }
        } else {
            $renderer = new Renderer();
            foreach ($errors as $error) {
                $renderer->flash(strtoupper($error[0]), $error[1]);
            }
        }
        unset($renderer);
        $_SESSION["authorization"]["errors"] = $errors;
        $_SESSION["authorization"]["values"] = $values;
        $route->redirect("/object/$idobject/right/add", "authorization");
    }
)

/** Delete a right for an object */
->get(
    "authorization/object/{idobject}/right/{idright}/delete/{token}",
    function ($idobject, $idright, $token) use ($authentication, $route) {
        $authHTML = $authentication->verifAuthHTML();
        // Delete a right if the CSRF token is correct
        $csrf = new Csrf();
        $renderer = new Renderer();
        try {
            $csrf->checkToken($token);
            $rights = new Rights($authHTML);
            $rights->delByID($idright);
            $route->redirect("/object/$idobject/right", "authorization");
        } catch (\Exception $e) {
            $renderer->flash("ERROR", $e->getMessage());
            $route->redirect("/object/$idobject/right", "authorization");
        }
    }
)

/** Edit an existing right for an object : display the form */
->get(
    "authorization/object/{idobject}/right/{idright}",
    function ($idobject, $idright) use ($authentication, $route) {
        $authHTML = $authentication->verifAuthHTML();
        $objects = new Objects($authHTML);
        $object = $objects->readByID($idobject);
        if (count($object) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Object not found"));
            $route->redirect("/object", "authorization");
        }

        $groups = new Groups($authHTML);
        $groupNames = $groups->read();
        $rights = new Rights($authHTML);
        $rightTypes = $rights->types();
        $values = $rights->readByID($idright);
        $objectName = $object[0]["object"];
        RendererAuthorization::html(
            "Modules\Authorization\Views\Rights",
            "updateObject",
            array("idobject" => $idobject,
                                      "objectName" => $objectName,
                                      "groupNames" => $groupNames,
                                      "rightTypes" => $rightTypes,
                                      "values" => $values,
                              )
        );
    }
)

/** Edit an existing right for an object : save the data */
->post(
    "authorization/object/{idobject}/right/{idright}",
    function ($idobject, $idright) use ($authentication, $route) {
        $authHTML = $authentication->verifAuthHTML();
        $objects = new Objects($authHTML);
        $object = $objects->readByID($idobject);
        if (count($object) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Object not found"));
            $route->redirect("/object", "authorization");
        }
        $renderer = new Renderer();
        $f = new Form();
        $values = $f->values();
        $rights = new Rights($authHTML);
        // Test the values before adding entry
        $errors = $rights->verify($values, $idright);
        if (count($errors) === 0) {
            try {
                $rights->updateByID(
                    $idright,
                    $values["idobject"],
                    $values["right"],
                    $values["comment"]
                );
                $route->redirect("/object/$idobject/right", "authorization");
            } catch (\Exception $e) {
                $renderer->flash("ERROR", $e->getMessage());
            }
        } else {
            $renderer = new Renderer();
            foreach ($errors as $error) {
                $renderer->flash(strtoupper($error[0]), $error[1]);
            }
        }
        unset($renderer);
        $_SESSION["authorization"]["errors"] = $errors;
        $_SESSION["authorization"]["values"] = $values;
        $route->redirect("/object/$idobject/right/$idright", "authorization");
    }
)

// RIGHTS ASSOCIATED TO A GROUP : AUTH TO BE DONE
->get(
    "authorization/group/{idgroup}/right",
    function ($idgroup) use ($authentication, $route) {
        // Display the list of objects already associated to the idgroup with the
        // associated right
        $authHTML = $authentication->verifAuthHTML();
        $group = new Groups($authHTML);
        $groups = $group->readByID($idgroup);
        if (count($groups) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }
        $groupNames = $group->read();
        $rights = new Rights($authHTML);
        $values = $rights->readByGroupByID($idgroup);
        $rightTypes = $rights->types();
        $titles = $rights->titles();
        $objects = new Objects($authHTML);
        $objectNames = $objects->read();
        RendererAuthorization::html(
            "Modules\Authorization\Views\Rights",
            "readGroup",
            array("rights" => $values,
                                      "titles" => $titles,
                                      "idgroup" => $idgroup,
                                      "group" => $groups[0]["group"],
                                      "groupNames" => $groupNames,
                                      "objectNames" => $objectNames,
                                      "rightTypes" => $rightTypes,
                                     )
        );
    }
)

->get(
    "authorization/group/{idgroup}/right/add",
    function ($idgroup) use ($authentication, $route) {
        // Display all the available objects and the availables rights to add a new
        // right for this group
        $authHTML = $authentication->verifAuthHTML();
        $group = new Groups($authHTML);
        $groups = $group->readByID($idgroup);
        if (count($groups) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }

        $object = new Objects($authHTML);
        $objects = $object->read();
        $newobjects = array();
        foreach ($objects as $obj) {
            $newobjects[$obj["idobject"]] = $obj ["object"];
        }

        $right = new Rights($authHTML);
        $rightTypes = $right->types();
        RendererAuthorization::html(
            "Modules\Authorization\Views\Rights",
            "updateGroup",
            array("objects" => $newobjects,
                                      "rightTypes" => $rightTypes,
                                      "idgroup" => $idgroup,
                                      "group" => $groups[0]["group"])
        );
    }
)

->post(
    "authorization/group/{idgroup}/right/add",
    function ($idgroup) use ($authentication, $route) {
        // Save the new right for a group
        $authHTML = $authentication->verifAuthHTML();
        $group = new Groups($authHTML);
        $groups = $group->readByID($idgroup);
        if (count($groups) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }
        $renderer = new Renderer();
        $f = new Form();
        $values = $f->values();
        $rights = new Rights($authHTML);
        // Test the values before adding entry
        $errors = $rights->verify($values);
        if (count($errors) === 0) {
            try {
                $rights->addByID(
                    $values["idgroup"],
                    $values["idobject"],
                    $values["right"],
                    $values["comment"]
                );
                $route->redirect("/group/$idgroup/right", "authorization");
            } catch (\Exception $e) {
                $renderer->flash("ERROR", $e->getMessage());
            }
        } else {
            $renderer = new Renderer();
            foreach ($errors as $error) {
                $renderer->flash(strtoupper($error[0]), $error[1]);
            }
        }
        unset($renderer);
        $_SESSION["authorization"]["errors"] = $errors;
        $_SESSION["authorization"]["values"] = $values;
        $route->redirect("/group/$idgroup/right/add", "authorization");
    }
)

->get(
    "authorization/group/{idgroup}/right/{idright}/delete/{token}",
    function ($idgroup, $idright, $token) use ($authentication, $route) {
        $authHTML = $authentication->verifAuthHTML();
        // Delete a right if the CSRF token is correct
        $csrf = new Csrf();
        $renderer = new Renderer();
        try {
            $csrf->checkToken($token);
            $rights = new Rights($authHTML);
            $rights->delByID($idright);
            $route->redirect("/group/$idgroup/right", "authorization");
        } catch (\Exception $e) {
            $renderer->flash("ERROR", $e->getMessage());
            $route->redirect("/group/$idgroup/right", "authorization");
        }
    }
)

->get(
    "authorization/group/{idgroup}/right/{idright}",
    function ($idgroup, $idright) use ($authentication, $route) {
        $authHTML = $authentication->verifAuthHTML();
        // Edit an existing right for a group
        $group = new Groups($authHTML);
        $groups = $group->readByID($idgroup);
        if (count($groups) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }

        $object = new Objects($authHTML);
        $objects = $object->read();
        $newobjects = array();
        foreach ($objects as $obj) {
            $newobjects[$obj["idobject"]] = $obj ["object"];
        }

        $rights = new Rights($authHTML);
        $rightTypes = $rights->types();
        $values = $rights->readByID($idright);
        RendererAuthorization::html(
            "Modules\Authorization\Views\Rights",
            "updateGroup",
            array("objects" => $newobjects,
                                      "rightTypes" => $rightTypes,
                                      "idgroup" => $idgroup,
                                      "values" => $values,
                                      "group" => $groups[0]["group"])
        );
    }
)

->post(
    "authorization/group/{idgroup}/right/{idright}",
    function ($idgroup, $idright) use ($authentication, $route) {
        $authHTML = $authentication->verifAuthHTML();
        // Save the edited right
        $group = new Groups($authHTML);
        $groups = $group->readByID($idgroup);
        if (count($groups) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }
        $renderer = new Renderer();
        $f = new Form();
        $values = $f->values();
        $rights = new Rights($authHTML);
        // Test the values before adding entry
        $errors = $rights->verify($values, $idright);
        if (count($errors) === 0) {
            try {
                $rights->updateByID(
                    $idright,
                    $values["idobject"],
                    $values["right"],
                    $values["comment"]
                );
                $route->redirect("/group/$idgroup/right", "authorization");
            } catch (\Exception $e) {
                $renderer->flash("ERROR", $e->getMessage());
            }
        } else {
            $renderer = new Renderer();
            foreach ($errors as $error) {
                $renderer->flash(strtoupper($error[0]), $error[1]);
            }
        }
        unset($renderer);
        $_SESSION["authorization"]["errors"] = $errors;
        $_SESSION["authorization"]["values"] = $values;
        $route->redirect("/group/$idgroup/right/$idright", "authorization");
    }
)

// GROUPS : AUTH TO BE DONE
->get(
    "authorization/",
    function () use ($authentication, $route) {
        $route->redirect("/authorization/group", "");
    }
)
->get(
    "authorization",
    function () use ($authentication, $route) {
        $route->redirect("/authorization/group", "");
    }
)

->get(
    "authorization/group",
    function () use ($authentication, $route) {
        // All the groups in the system
        $authHTML = $authentication->verifAuthHTML();
        $groups = new Groups($authHTML);
        $values = $groups->read();
        $titles = $groups->titles();
        RendererAuthorization::html(
            "Modules\Authorization\Views\Groups",
            "read",
            array("groups" => $values, "titles" => $titles)
        );
    }
)

->get(
    "authorization/group/add",
    function () use ($authentication, $route) {
        // The editing page to add a new group
        $authHTML = $authentication->verifAuthHTML();
        RendererAuthorization::html(
            "Modules\Authorization\Views\Groups",
            "update",
            ""
        );
    }
)

->post(
    "authorization/group/add",
    function () use ($authentication, $route) {
        // Add a new group in the database
        $authHTML = $authentication->verifAuthHTML();
        $renderer = new Renderer();
        $f = new Form();
        $values = $f->values();
        $groups = new Groups($authHTML);
        // Test the values before adding entry
        $errors = $groups->verify($values);
        if (count($errors) === 0) {
            try {
                $groups->add($values["group"], $values["comment"]);
                //$renderer->flash ("SUCCESS", _("Creation done"));
                $route->redirect("/group", "authorization");
            } catch (\Exception $e) {
                $renderer->flash("ERROR", $e->getMessage());
            }
        } else {
            $renderer = new Renderer();
            foreach ($errors as $error) {
                $renderer->flash(strtoupper($error[0]), $error[1]);
            }
        }
        unset($renderer);
        $_SESSION["authorization"]["errors"] = $errors;
        $_SESSION["authorization"]["values"] = $values;
        $route->redirect("/group/add", "authorization");
    }
)

->get(
    "authorization/group/{idgroup}/delete/{token}",
    function ($idgroup, $token) use ($authentication, $route) {
        $authHTML = $authentication->verifAuthHTML();
        // Delete a group if the CSRF token is correct
        $csrf = new Csrf();
        $renderer = new Renderer();
        try {
            $csrf->checkToken($token);
            $groups = new Groups($authHTML);
            $groups->delByID($idgroup);
            $route->redirect("/group", "authorization");
        } catch (\Exception $e) {
            $renderer->flash("ERROR", $e->getMessage());
            $route->redirect("/group", "authorization");
        }
    }
)

->get(
    "authorization/group/{idgroup}",
    function ($idgroup) use ($authentication, $route) {
        // Edit an existing group
        $authHTML = $authentication->verifAuthHTML();
        $groups = new Groups($authHTML);
        $values = $groups->readByID($idgroup);
        if (count($values) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Group not found"));
            $route->redirect("/group", "authorization");
        }
        RendererAuthorization::html(
            "Modules\Authorization\Views\Groups",
            "update",
            array("values" => $values)
        );
    }
)

->post(
    "authorization/group/{idgroup}",
    function ($idgroup) use ($authentication, $route) {
        // Save an edit of an existing group
        $authHTML = $authentication->verifAuthHTML();
        $renderer = new Renderer();
        $f = new Form();
        $values = $f->values();
        $groups = new Groups($authHTML);
        // Test the values before adding entry
        $errors = $groups->verify($values, $idgroup);
        if (count($errors) === 0) {
            try {
                $groups->updateByID($idgroup, $values["group"], $values["comment"]);
                $route->redirect("/group", "authorization");
            } catch (\Exception $e) {
                $renderer->flash("ERROR", $e->getMessage());
            }
        } else {
            $renderer = new Renderer();
            foreach ($errors as $error) {
                $renderer->flash(strtoupper($error[0]), $error[1]);
            }
        }
        unset($renderer);
        $_SESSION["authorization"]["errors"] = $errors;
        $_SESSION["authorization"]["values"] = $values;
        $route->redirect("/group/$idgroup", "authorization");
    }
)

// OBJECTS : AUTH TO BE DONE
->get(
    "authorization/object",
    function () use ($authentication, $route) {
        // Display all the objects in the system
        $authHTML = $authentication->verifAuthHTML();
        $objects = new Objects($authHTML);
        $values = $objects->read();
        $titles = $objects->titles();
        RendererAuthorization::html(
            "Modules\Authorization\Views\Objects",
            "read",
            array("objects" => $values, "titles" => $titles)
        );
    }
)

->get(
    "authorization/object/add",
    function () use ($authentication, $route) {
        // The editing page to add a new object
        $authHTML = $authentication->verifAuthHTML();
        RendererAuthorization::html(
            "Modules\Authorization\Views\Objects",
            "update",
            ""
        );
    }
)

->post(
    "authorization/object/add",
    function () use ($authentication, $route) {
        // Add a new object in the database
        $authHTML = $authentication->verifAuthHTML();
        $renderer = new Renderer();
        $f = new Form();
        $values = $f->values();
        $objects = new Objects($authHTML);
        // Test the values before adding entry
        $errors = $objects->verify($values);
        if (count($errors) === 0) {
            try {
                $objects->add($values["object"], $values["comment"]);
                //$renderer->flash ("SUCCESS", _("Creation done"));
                $route->redirect("/object", "authorization");
            } catch (\Exception $e) {
                $renderer->flash("ERROR", $e->getMessage());
            }
        } else {
            $renderer = new Renderer();
            foreach ($errors as $error) {
                $renderer->flash(strtoupper($error[0]), $error[1]);
            }
        }
        unset($renderer);
        $_SESSION["authorization"]["errors"] = $errors;
        $_SESSION["authorization"]["values"] = $values;
        $route->redirect("/object/add", "authorization");
    }
)

->get(
    "authorization/object/{idobject}/delete/{token}",
    function ($idobject, $token) use ($authentication, $route) {
        // Delete a object if the CSRF token is correct
        $authHTML = $authentication->verifAuthHTML();
        $csrf = new Csrf();
        $renderer = new Renderer();
        try {
            $csrf->checkToken($token);
            $objects = new Objects($authHTML);
            $objects->delByID($idobject);
            $route->redirect("/object", "authorization");
        } catch (\Exception $e) {
            $renderer->flash("ERROR", $e->getMessage());
            $route->redirect("/object", "authorization");
        }
    }
)

->get(
    "authorization/object/{idobject}",
    function ($idobject) use ($authentication, $route) {
        // Edit an existing object
        $authHTML = $authentication->verifAuthHTML();
        $objects = new Objects($authHTML);
        $values = $objects->readByID($idobject);
        if (count($values) === 0) {
            $renderer = new Renderer();
            $renderer->flash("ERROR", _("Object not found"));
            $route->redirect("/object", "authorization");
        }
        RendererAuthorization::html(
            "Modules\Authorization\Views\Objects",
            "update",
            array("values" => $values)
        );
    }
)

->post(
    "authorization/object/{idobject}",
    function ($idobject) use ($authentication, $route) {
        // Save an edit of an existing object
        $authHTML = $authentication->verifAuthHTML();
        $renderer = new Renderer();
        $f = new Form();
        $values = $f->values();
        $objects = new Objects($authHTML);
        // Test the values before adding entry
        $errors = $objects->verify($values, $idobject);
        if (count($errors) === 0) {
            try {
                $objects->updateByID($idobject, $values["object"], $values["comment"]);
                $route->redirect("/object", "authorization");
            } catch (\Exception $e) {
                $renderer->flash("ERROR", $e->getMessage());
            }
        } else {
            $renderer = new Renderer();
            foreach ($errors as $error) {
                $renderer->flash(strtoupper($error[0]), $error[1]);
            }
        }
        unset($renderer);
        $_SESSION["authorization"]["errors"] = $errors;
        $_SESSION["authorization"]["values"] = $values;
        $route->redirect("/object/$idobject", "authorization");
    }
);
