<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Tests\Controllers;

use Controllers\Userprefs;
use Domframework\Authzgroups;
use Models\Configuration;
use Models\Userpref;
use Models\Zone;

/** Test the controller_userprefs.php file */
class UserprefsTest extends \PHPUnit_Framework_TestCase
{
    public function testCreateAuthzDB()
    {
        @unlink("/tmp/database.db");
        $configuration = new Configuration();
        $dbconfig = $configuration->get("database");
        if (! isset($dbconfig["tableprefix"])) {
            $dbconfig["tableprefix"] = "";
        }
        $n = new Authzgroups();
        $n->connect(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $n->tableprefix = $dbconfig["tableprefix"];
        $res = $n->createTables();
        $n->disconnect();
        unset($n);
        $a = new Authzgroups();
        $a->connect(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $a->tableprefix = $dbconfig["tableprefix"];
        $a->groupAdd("domdns", "TEST");
        $a->groupmemberAdd("domdns", "TEST", "anonymous");
        $a->objectAdd("domdns", "/");
        $a->rightAdd("domdns", "TEST", "/", "RW");
        $a->disconnect();
        $this->assertSame(true, $res);
    }

    public function testCreateDB()
    {
        // Must use the model to create the database structure
        $configuration = new Configuration();
        $this->dbconfig = $configuration->get("database");
        if (! isset($this->dbconfig["tableprefix"])) {
            $this->dbconfig["tableprefix"] = "";
        }

        $n = new Userpref(
            $this->dbconfig["dsn"],
            $this->dbconfig["username"],
            $this->dbconfig["password"],
            $this->dbconfig["driver_options"]
        );
        $n->tableprefix = $this->dbconfig["tableprefix"];
        $res = $n->createTable();
        $n->disconnect();
        $z = new Zone(
            $this->dbconfig["dsn"],
            $this->dbconfig["username"],
            $this->dbconfig["password"],
            $this->dbconfig["driver_options"]
        );
        $z->tableprefix = $this->dbconfig["tableprefix"];
        $z->createTable();
        $res = $z->insert(array("zone" => "zone.", "viewname" => "default",
                       "opendate" => gmdate("Y-m-d H:i:s")));
        $z->disconnect();
        $a = new Authzgroups();
        $a->connect(
            $this->dbconfig["dsn"],
            $this->dbconfig["username"],
            $this->dbconfig["password"],
            $this->dbconfig["driver_options"]
        );
        $a->tableprefix = $this->dbconfig["tableprefix"];
        $a->objectAdd("domdns", "/zone./default");
        $a->rightAdd("domdns", "TEST", "/zone./default", "RW");
        $a->disconnect();
        $this->assertSame("1", $res);
    }

    public function testReadEmpty()
    {
        $n = new Userprefs(["email" => "anonymous"]);
        $res = $n->read("emptyuser", "emptykey");
        $this->assertSame(array(), $res);
    }

    public function testInsert()
    {
        $configuration = new Configuration();
        $this->dbconfig = $configuration->get("database");
        if (! isset($this->dbconfig["tableprefix"])) {
            $this->dbconfig["tableprefix"] = "";
        }

        $z = new Zone(
            $this->dbconfig["dsn"],
            $this->dbconfig["username"],
            $this->dbconfig["password"],
            $this->dbconfig["driver_options"]
        );
        $z->tableprefix = $this->dbconfig["tableprefix"];
        $z->disconnect();

        $n = new Userprefs(["email" => "anonymous"]);
        $res = $n->insert(array("user" => "anonymous",
                              "key" => "autoactivate-zone./default",
                              "value" => "value"));
        $n->disconnect();
        $this->assertSame('1', $res);
    }

    public function testReadOK()
    {
        $n = new Userprefs(["email" => "anonymous"]);
        $res = $n->read("autoactivate-zone./default");
        $n->disconnect();
        unset($res["lastread"]);
        unset($res["lastupdate"]);
        $this->assertSame(array("id" => "1",
                              "user" => "anonymous",
                              "key" => "autoactivate-zone./default",
                              "value" => "value"), $res);
    }

    public function testUpdate1()
    {
        $n = new Userprefs(["email" => "anonymous"]);
        $res = $n->read("autoactivate-zone./default");
        $lastupdate = $res["lastupdate"];
        $lastread = $res["lastread"];
        $res = $n->update("autoactivate-zone./default", "value2");
        $n->disconnect();
        $this->assertSame(1, $res);
    }

    public function testClean()
    {
        // Must use the model to drop the database structure
        $configuration = new Configuration();
        $this->dbconfig = $configuration->get("database");
        if (! isset($this->dbconfig["tableprefix"])) {
            $this->dbconfig["tableprefix"] = "";
        }

        $n = new Userpref(
            $this->dbconfig["dsn"],
            $this->dbconfig["username"],
            $this->dbconfig["password"],
            $this->dbconfig["driver_options"]
        );
        $n->tableprefix = $this->dbconfig["tableprefix"];
        $res = $n->dropTable();
        $n->disconnect();
        $z = new Zone(
            $this->dbconfig["dsn"],
            $this->dbconfig["username"],
            $this->dbconfig["password"],
            $this->dbconfig["driver_options"]
        );
        $z->tableprefix = $this->dbconfig["tableprefix"];
        $z->dropTable();
        $z->disconnect();
        unlink("/tmp/database.db");
        $this->assertSame(0, $res);
    }
}
