<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Tests\Controllers;

use Controllers\Zones;
use Domframework\Authzgroups;
use Models\Configuration;
use Models\Record;
use Models\Userpref;
use Models\Zone;

/** Test the controller_zones.php file */
class ZonesTest extends \PHPUnit_Framework_TestCase
{
    public function testCreateAuthzDB()
    {
        @unlink("/tmp/database.db");
        $configuration = new Configuration();
        $dbconfig = $configuration->get("database");
        if (! isset($dbconfig["tableprefix"])) {
            $dbconfig["tableprefix"] = "";
        }
        $n = new Authzgroups();
        $n->connect(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $n->tableprefix = $dbconfig["tableprefix"];
        $res = $n->createTables();
        $n->disconnect();
        unset($n);
        $n = new Authzgroups();
        $n->connect(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $n->tableprefix = $dbconfig["tableprefix"];
        $n->groupAdd("domdns", "TEST");
        $n->groupmemberAdd("domdns", "TEST", "anonymous");
        $n->objectAdd("domdns", "/");
        $n->rightAdd("domdns", "TEST", "/", "RW");
        $n->disconnect();
        $this->assertSame(true, $res);
    }

    public function testCreateUserPrefDB()
    {
        $configuration = new Configuration();
        $dbconfig = $configuration->get("database");
        if (! isset($dbconfig["tableprefix"])) {
            $dbconfig["tableprefix"] = "";
        }
        $n = new Userpref(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $n->tableprefix = $dbconfig["tableprefix"];
        $res = $n->createTable();
        $n->disconnect();
        $this->assertSame(0, $res);
    }

    public function testCreateDB()
    {
        // Must use the model to create the database structure as there is no
        // creation of tables in controller
        $configuration = new Configuration();
        $dbconfig = $configuration->get("database");
        if (! isset($dbconfig["tableprefix"])) {
            $dbconfig["tableprefix"] = "";
        }

        $z = new Zone(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $z->tableprefix = $dbconfig["tableprefix"];
        $res = $z->createTable();
        $z->disconnect();
        $r = new Record(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $r->tableprefix = $dbconfig["tableprefix"];
        $r->createTable();
        $r->disconnect();
        $this->assertSame(0, $res);
    }

    public function testAddZoneBad1()
    {
        $z = new Zones(["email" => "anonymous"]);
        $this->setExpectedException("Exception");
        $res = $z->insert(array("zone" => "","viewname" => ""));
        $z->disconnect();
    }

    public function testAddZoneBad2()
    {
        $z = new Zones(["email" => "anonymous"]);
        $this->setExpectedException("Exception");
        $res = $z->insert(array("zone" => "XX.","viewname" => ""));
    }

    public function testAddZoneBad3()
    {
        $z = new Zones(["email" => "anonymous"]);
        $this->setExpectedException("Exception");
        $res = $z->insert(array("zone" => "XX","viewname" => ""));
    }


    public function testAddZoneOK1()
    {
        $z = new Zones(["email" => "anonymous"]);
        $res = $z->insert(array("zone" => "xx.","viewname" => "i"));
        $this->assertSame('1', $res);
    }

    public function testReadZone1()
    {
        $z = new Zones(["email" => "anonymous"]);
        $res = $z->read();
        $this->assertSame(1, count($res));
    }

    public function testUpdateZone()
    {
        $z = new Zones(["email" => "anonymous"]);
        $res = $z->update("xx.", "i", array("viewname" => "newview"));
        $this->assertSame(true, $res);
    }

    public function testReadZone2()
    {
        $z = new Zones(["email" => "anonymous"]);
        $res = $z->read();
        $this->assertSame("newview", $res[0]["viewname"]);
    }

    public function testDeleteZone()
    {
        $z = new Zones(["email" => "anonymous"]);
        $res = $z->delete("xx.", "newview");
        $this->assertSame(1, $res);
    }

    public function testDropTable()
    {
        // Must use the model to drop the database structure as there is no
        // creation of tables in controller
        $configuration = new Configuration();
        $dbconfig = $configuration->get("database");
        if (! isset($dbconfig["tableprefix"])) {
            $dbconfig["tableprefix"] = "";
        }

        $z = new Zone(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $z->tableprefix = $dbconfig["tableprefix"];
        $res = $z->dropTable();
        $r = new Record(
            $dbconfig["dsn"],
            $dbconfig["username"],
            $dbconfig["password"],
            $dbconfig["driver_options"]
        );
        $r->tableprefix = $dbconfig["tableprefix"];
        $r->dropTable();
        $this->assertSame(0, $res);
    }
}
