<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Tests\Models;

use Models\Bind;

/** Test the model_bind.php file */
class BindTest extends \PHPUnit_Framework_TestCase
{
    public function testBindImport1()
    {
        @unlink("/tmp/database.db");
        $bind = new Bind();
        $res = $bind->import("domdns  3600  IN A  82.67.68.81", "fournier38.fr.");
        $this->assertSame(array(array("source" => "domdns",
                                     "class" => "IN",
                                     "rr" => "A",
                                     "addvalues" => "",
                                     "target" => "82.67.68.81",
                                     "ttl" => "3600",
                                     "comment" => "",
                                     "closedate" => "")), $res);
    }

    public function testBindImport2()
    {
        $bind = new Bind();
        $res = $bind->import("domdns  IN A  82.67.68.81", "fournier38.fr.");
        $this->assertSame(array(array("source" => "domdns",
                                     "class" => "IN",
                                     "rr" => "A",
                                     "addvalues" => "",
                                     "target" => "82.67.68.81",
                                     "ttl" => "3600",
                                     "comment" => "",
                                     "closedate" => "")), $res);
    }

    public function testBindImport3()
    {
        $bind = new Bind();
        $res = $bind->import(
            "domdns  IN A  82.67.68.81;multiple comment ",
            "fournier38.fr."
        );
        $this->assertSame(array(array("source" => "domdns",
                                     "class" => "IN",
                                     "rr" => "A",
                                     "addvalues" => "",
                                     "target" => "82.67.68.81",
                                     "ttl" => "3600",
                                     "comment" => "multiple comment",
                                     "closedate" => "")), $res);
    }

    public function testBindImportParenthesisOneLine1()
    {
        $bind = new Bind();
        $res = $bind->import(
            "@                         3600  IN SOA" .
                          "             ns1.fournier38.fr. " .
                          "dominique.fournier38.fr. ( 2014070123 3600 900 " .
                          "604800 3600 )    ; commentaire !!",
            "fournier38.fr."
        );
        $this->assertSame(array(array("source" => "@",
                                     "class" => "IN",
                                     "rr" => "SOA",
                                     "addvalues" => "",
                                     "target" => "ns1.fournier38.fr. " .
                                       "dominique.fournier38.fr. ( 2014070123 " .
                                       "3600 900 604800 3600 )",
                                     "ttl" => "3600",
                                     "comment" => "commentaire !!",
                                     "closedate" => "")), $res);
    }

    public function testBindImportParenthesisMultipleLines1()
    {
        $bind = new Bind();
        $res = $bind->import(
            "@                         3600  IN SOA" .
                          "             ns1.fournier38.fr. " .
                          "dominique.fournier38.fr. ( 2014070123 3600 900\n" .
                          "604800 3600 )    ; commentaire !!",
            "fournier38.fr."
        );
        $this->assertSame(array(array("source" => "@",
                                     "class" => "IN",
                                     "rr" => "SOA",
                                     "addvalues" => "",
                                     "target" => "ns1.fournier38.fr. " .
                                       "dominique.fournier38.fr. ( 2014070123 " .
                                       "3600 900 604800 3600 )",
                                     "ttl" => "3600",
                                     "comment" => "commentaire !!",
                                     "closedate" => "")), $res);
    }


    public function testBindImport5()
    {
        $bind = new Bind();
        $res = $bind->import(
            "_xmpp-client._tcp         3600  IN SRV            " .
                          " 5 0  5222    xmpp.fournier38.fr.",
            "fournier38.fr."
        );
        $this->assertSame(array(array("source" => "_xmpp-client._tcp",
                                     "class" => "IN",
                                     "rr" => "SRV",
                                     "addvalues" => "",
                                     "target" => "5 0 5222 xmpp.fournier38.fr.",
                                     "ttl" => "3600",
                                     "comment" => "",
                                     "closedate" => "")), $res);
    }

    public function testBindImport6()
    {
        $bind = new Bind();
        $res = $bind->import(
            "_xmpp-client._tcp         3600  IN SRV             " .
                          " 5 0  5222    xmpp.fournier38.fr. ; Comment",
            "fournier38.fr."
        );
        $this->assertSame(array(array("source" => "_xmpp-client._tcp",
                                     "class" => "IN",
                                     "rr" => "SRV",
                                     "addvalues" => "",
                                     "target" => "5 0 5222 xmpp.fournier38.fr.",
                                     "ttl" => "3600",
                                     "comment" => "Comment",
                                     "closedate" => "")), $res);
    }

    public function testBindImport7()
    {
        $bind = new Bind();
        $res = $bind->import(
            'default._domainkey      IN      TXT     ( "v=DKIM1; h=rsa-sha256; k=rsa; s=email; "
          "p=MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzrINihZ+LbCRgwSJeXB65Sg85uNNy89xVq8KJPUYM7AFS8+4xwkQToTxPExbzvBPU9N5ja7wzLFxDoqXI1xTTTQqydjztESN71H4VRJ+G0NTnMFYkG33u+abrtcWenM98DOw1lWwadDm0zGS48ihjR8BJ08lZMNth6wU2adHtM108eHGa5gmZn/oaxfYyYufdwTxLwC/FY63By"
          "uLegndOB5oydHJMf2z/kUprXpxUmL/9uk+GNvTKcy2RrD2dYx96yIohr1PH4G+fpiIcaUXhoOWDt2HCmprgkaFe0jK7ByNTGaxjElAhPPtHan4pEYCGzsqS85nuQi+uypXHwZNOwIDAQAB" )  ; ----- DKIM key default for example.com',
            "fournier38.fr."
        );
        $this->assertSame(array(array("source" => "default._domainkey",
                                     "class" => "IN",
                                     "rr" => "TXT",
                                     "addvalues" => "",
                                     "target" => '( "v=DKIM1; h=rsa-sha256; k=rsa; s=email; " ' .
        '"p=MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAzrINihZ+LbCRgwSJeXB65Sg85uNNy89xVq8KJPUYM7AFS8+4xwkQToTxPExbzvBPU9N5ja7wzLFxDoqXI1xTTTQqydjztESN71H4VRJ+G0NTnMFYkG33u+abrtcWenM98DOw1lWwadDm0zGS48ihjR8BJ08lZMNth6wU2adHtM108eHGa5gmZn/oaxfYyYufdwTxLwC/FY63By" ' .
        '"uLegndOB5oydHJMf2z/kUprXpxUmL/9uk+GNvTKcy2RrD2dYx96yIohr1PH4G+fpiIcaUXhoOWDt2HCmprgkaFe0jK7ByNTGaxjElAhPPtHan4pEYCGzsqS85nuQi+uypXHwZNOwIDAQAB" )',
                                     "ttl" => "3600",
                                     "comment" => "----- DKIM key default for example.com",
                                     "closedate" => "")), $res);
    }
}
