<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Tests\Models;

use Models\Zone;

/** Test the model_zone.php file */
class ZoneTest extends \PHPUnit_Framework_TestCase
{
    public function testAddDisable1()
    {
        // Open since one hour
        $zone = new Zone("sqlite::memory:");
        $time = time();
        $zoneData = array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time - 3600),
                              "closedate" => ""));
        $res = $zone->addDisable($zoneData);
        $this->assertSame(
            $res,
            array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time - 3600),
            "closedate" => "",
            "disabled" => false))
        );
    }

    public function testAddDisable2()
    {
        // Open in one hour
        $zone = new Zone("sqlite::memory:");
        $time = time();
        $zoneData = array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time + 3600),
                              "closedate" => ""));
        $res = $zone->addDisable($zoneData);
        $this->assertSame(
            $res,
            array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time + 3600),
            "closedate" => "",
            "disabled" => true))
        );
    }

    public function testAddDisable3()
    {
        // Open in one hour and close in two hours
        $zone = new Zone("sqlite::memory:");
        $time = time();
        $zoneData = array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time + 3600),
                              "closedate" => date("Y-m-d H:i:s", $time + 7200)));
        $res = $zone->addDisable($zoneData);
        $this->assertSame(
            $res,
            array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time + 3600),
                              "closedate" => date("Y-m-d H:i:s", $time + 7200),
            "disabled" => true))
        );
    }

    public function testAddDisable4()
    {
        // Open since one hour and close in two hours
        $zone = new Zone("sqlite::memory:");
        $time = time();
        $zoneData = array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time - 3600),
                              "closedate" => date("Y-m-d H:i:s", $time + 7200)));
        $res = $zone->addDisable($zoneData);
        $this->assertSame(
            $res,
            array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time - 3600),
                              "closedate" => date("Y-m-d H:i:s", $time + 7200),
            "disabled" => false))
        );
    }

    public function testAddDisable5()
    {
        // Open since two hours and close since one hour
        $zone = new Zone("sqlite::memory:");
        $time = time();
        $zoneData = array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time - 7200),
                              "closedate" => date("Y-m-d H:i:s", $time - 3600)));
        $res = $zone->addDisable($zoneData);
        $this->assertSame(
            $res,
            array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time - 7200),
                              "closedate" => date("Y-m-d H:i:s", $time - 3600),
            "disabled" => true))
        );
    }

    public function testAddDisable6()
    {
        // In the past, the closing date is before the openning date
        $zone = new Zone("sqlite::memory:");
        $time = time();
        $zoneData = array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time - 3600),
                              "closedate" => date("Y-m-d H:i:s", $time - 7200)));
        $res = $zone->addDisable($zoneData);
        $this->assertSame(
            $res,
            array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time - 3600),
                              "closedate" => date("Y-m-d H:i:s", $time - 7200),
            "disabled" => false))
        );
    }

    public function testAddDisable7()
    {
        // In the future, the closing date is before the openning date
        // The zone is actually enable, will be closed in 3600s, and reopen in 7200s
        $zone = new Zone("sqlite::memory:");
        $time = time();
        $zoneData = array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time + 7200),
                              "closedate" => date("Y-m-d H:i:s", $time + 3600)));
        $res = $zone->addDisable($zoneData);
        $this->assertSame(
            $res,
            array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time + 7200),
                              "closedate" => date("Y-m-d H:i:s", $time + 3600),
            "disabled" => false))
        );
    }

    public function testAddDisable8()
    {
        // the closing date is before the openning date, with the closing in past
        $zone = new Zone("sqlite::memory:");
        $time = time();
        $zoneData = array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time + 7200),
                              "closedate" => date("Y-m-d H:i:s", $time - 3600)));
        $res = $zone->addDisable($zoneData);
        $this->assertSame(
            $res,
            array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time + 7200),
                              "closedate" => date("Y-m-d H:i:s", $time - 3600),
            "disabled" => true))
        );
    }

    public function testAddDisable9()
    {
        // the closing date is equal the openning date, with the date in past
        $zone = new Zone("sqlite::memory:");
        $time = time();
        $zoneData = array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time - 3600),
                              "closedate" => date("Y-m-d H:i:s", $time - 3600)));
        $res = $zone->addDisable($zoneData);
        $this->assertSame(
            $res,
            array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time - 3600),
                              "closedate" => date("Y-m-d H:i:s", $time - 3600),
            "disabled" => true))
        );
    }

    public function testAddDisable10()
    {
        // the closing date is equal the openning date, with the date in future
        $zone = new Zone("sqlite::memory:");
        $time = time();
        $zoneData = array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time + 7200),
                              "closedate" => date("Y-m-d H:i:s", $time + 7200)));
        $res = $zone->addDisable($zoneData);
        $this->assertSame(
            $res,
            array(array("id" => 0,"zone" => "tst1","viewname" => "tst1",
                              "opendate" => date("Y-m-d H:i:s", $time + 7200),
                              "closedate" => date("Y-m-d H:i:s", $time + 7200),
            "disabled" => true))
        );
    }
}
