<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Views;

use Domframework\Csrf;
use Domframework\Form;
use Domframework\Formfield;
use Views\Viewerror;
use Views\Flash;

/** The view for Records */
class Records
{
    public function read($data, $variable)
    {
        // Can display the flash
        $dataflash = Flash::call();
        $content = $dataflash;

        // The HTML code to confirm the removal of entry
        $content .= "<!-- Confirmation of removal -->\n";
        $content .= "<div id='modalConfirmAction' class='modal fade' tabindex='-1' ";
        $content .= "role='dialog' aria-labelledby='myModalLabel' aria-hidden='true'>" .
              "\n";
        $content .= "  <div class='modal-dialog'>\n";
        $content .= "    <div class='modal-content'>\n";
        $content .= "      <div class='modal-header'>\n";
        $content .= "        <button type='button' class='close' data-dismiss='modal' ";
        $content .= "aria-hidden='true'>×</button>\n";
        $content .= "        <h3 class='modal-title' id='myModalLabel'>";
        $content .= _("Confirmation the removal") . "</h3>\n";
        $content .= "      </div>\n";
        $content .= "      <div id='modal-body-simple' style='display:none' " .
                "class='modal-body'>\n";
        $content .= "        " . _("Are you sure to remove the entry?") . "\n";
        $content .= "         <span class='modalConfirmAction_number'></span> " .
                          _("selection");
        $content .= "      </div>\n";
        $content .= "      <div id='modal-body-multiple' class='modal-body'>\n";
        $content .= "        " . _("Are you sure to remove the entries?") . "\n";
        $content .= "        <span class='modalConfirmAction_number'></span> " .
                         _("selections");
        $content .= "      </div>\n";
        $content .= "      <div class='modal-footer'>\n";
        $content .= "        <button type='button' class='btn btn-default' " .
                "data-dismiss='modal'>" . _("Cancel") . "</button>\n";
        $content .= "         <button type='button' class='btn btn-primary' " .
                "id='btn-delete'>" . _("Delete") . "</button>\n";
        $content .= "      </div>\n";
        $content .= "    </div>\n";
        $content .= "  </div>\n";
        $content .= "</div>\n";
        $content .= "<script>";
        $content .= "// Preload image\n";
        $content .= "var my_image = new Image();\n";
        $content .= "my_image.src = '{baseurl}public/ico/wait-transparent.gif';\n";
        $content .= "var msgDelete = '" . _("Delete") . "'\n";
        $content .= "</script>\n";
        $content .= "<!-- End of confirmation of removal -->\n";

        $zone = $data["zone"];
        if ($zone === ".") {
            $zoneURL = "dot";
        } else {
            $zoneURL = urlencode($zone);
        }
        $viewname = $data["viewname"];
        if ($viewname === ".") {
            $viewnameURL = "dot";
        } else {
            $viewnameURL = urlencode($viewname);
        }

        $readonly = $data["readonly"];
        $disabled = $data["disabled"];

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}zone'>" . _("Zones") .
                "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}zone/$zoneURL'>" .
                "$zone</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}zone/$zoneURL/$viewnameURL'>" .
                "$viewname</a>";
        $content .= "</li>\n";
        $content .= "</ol>\n";

        // Menu buttons
        if ($readonly === true) {
            $content .= "<div class='btn-group btn-sm'>\n";
            $content .= "<button id='readonly' type='button' disabled='disabled' ";
            $content .= "class='btn btn-info'>";
            $content .= _("Read-only zone") . "</button>\n";
            $content .= "</div>\n";
        } else {
            $content .= "<div class='btn-group btn-sm'>\n";
            $content .= "  <a id='add' class='btn btn-default' ";
            $content .= "href='{baseurlresource}zone/$zoneURL/$viewnameURL/add'";
            $content .= ">";
            $content .= _("Add") . "</a>\n";
            $content .= "  <button id='modify' type='button' ";
            $content .= "class='disabled btn btn-default'>";
            $content .= _("Modify") . "</button>\n";
            $content .= "  <button id='delete' type='button' ";
            $content .= "class='disabled btn btn-default'>";
            $content .= _("Delete") . "</button>\n";
            $content .= "  <a id='import' class='btn btn-default' ";
            $content .= "href='{baseurlresource}zone/$zoneURL/$viewnameURL/import'";
            $content .= ">";
            $content .= _("Import") . "</a>\n";
            $content .= "  <a id='exportBind' class='btn btn-default' ";
            $content .= "href='{baseurlresource}zone/$zoneURL/$viewnameURL.bind'";
            $content .= ">";
            $content .= _("Export") . "</a>\n";
            if (substr($zone, -6) === ".arpa.") {
                $content .= "  <a id='matrix' class='btn btn-default' ";
                $content .= "href='{baseurlresource}zone/$zoneURL/$viewnameURL/matrix'";
                $content .= ">";
                $content .= _("Matrix") . "</a>\n";
            }
            $content .= "</div>\n";

            $content .= "<div class='btn-group btn-sm'>\n";
            $content .= "  <button type='button' class='btn btn-default " .
                  "active' id='manual' style='width: 100px'>" .
                  _("Manual") . "/" . _("Automatic") .
                  "</button>\n";
            $content .= "<script>";
            if ($data["autoactivateZoneView"] === "0") {
                $content .= "zoneAutoActivate=0;";
            } else {
                $content .= "zoneAutoActivate=1;";
            }
            if ($data["autoactivateDefault"] === "0") {
                $content .= "zoneAutoActivateDefault=0;";
            } else {
                $content .= "zoneAutoActivateDefault=1;";
            }
            if ($data["disabled"] === true) {
                $content .= "disabled=true;";
            } else {
                $content .= "disabled=false;";
            }
            $content .= "</script>\n";
            $content .= "  <a id='zoneexport' class='btn btn-default' ";
            $content .= "href='{baseurlresource}zone/$zoneURL/$viewnameURL/" .
                  "servers/zoneexport'";
            $content .= ">";
            $content .= _("Push on DNS") . "</a>\n";
            $content .= "  <a id='serversreload' class='btn btn-default' ";
            $content .= "href='{baseurlresource}zone/$zoneURL/$viewnameURL/" .
                  "servers/reload'";
            $content .= ">";
            $content .= _("Activate the zone") . "</a>\n";
            $content .= "</div>\n";
            $content .= "<script src='{baseurl}public/js/zoneAutoActivate.js?t=" .
                  filemtime("public/js/zoneAutoActivate.js") . "'>";
            $content .= "</script>\n";
        }
        if ($data["disabled"] === true) {
            $content .= "<span class='label label-warning'>" . _("Disabled zone") .
                    "</span>";
        }


        $csrf = new Csrf();
        $content .= "<script>zone='$zone';viewname='$viewname';";
        $content .= "baseurl='{baseurl}';\n";
        $content .= "csrfToken='" . $csrf->createToken() . "';";
        $content .= "</script>\n";

        $content .= "<div class='table'>\n";
        if (count($data["values"]) === 0) {
            $error = new Viewerror();
            $content .= "  " . $error->html(_("No record found"), "");
            $content .= "</div>\n";
            return array("content" => $content,
               "title" => sprintf(
                   _("Edit record for zone '%s' and view '%s'"),
                   $zone,
                   $viewname
               ));
        }

        // The width is forbidden, but if thereis a style='width:100%', the table
        // don't change it's size when resizing the window from small to large.
        // I prefer to keep the width.
        $content .= "  <table id='data' class='table table-striped' " .
                "width='100%'>\n";
        // Titles
        $content .= "    <thead><tr>";
        foreach ($data["titles"] as $key => $title) {
            //if ($title === "id") continue;
            if ($key === "zoneid") {
                continue;
            }
            if ($key === "opendate") {
                continue;
            }
            if ($key === "closedate") {
                continue;
            }
            if ($key === "ttl") {
                continue;
            }
            $content .= "<th>" . $title . "</th>";
        }
        $content .= "<th>" . _("Details") . "</th>";
        $content .= "</tr></thead>\n";

        // Data
        $content .= "    <tbody>\n";
        $content .= "    </tbody>\n";
        $content .= "  </table>\n";
        $content .= "</div>\n";

        // Add dataTables
        //    $content .= "var table; var giRedraw = false;\n";
        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "jquery.dataTables.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/jquery.dataTables.min.js") .
                "'></script>\n";
        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "ip-address.js?t=" .
                filemtime("public/DataTables-1.10.12/js/ip-address.js") .
                "'></script>\n";
        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "ip-reverse.js?t=" .
                filemtime("public/DataTables-1.10.12/js/ip-reverse.js") .
                "'></script>\n";
        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "dataTables.bootstrap.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/dataTables.bootstrap.min.js")
                . "'></script>\n";
        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "dataTables.select.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/dataTables.select.min.js") .
                "'></script>\n";
        //    $content .= "<script src='{baseurl}public/datatables/selectDelete.js'>";
        //    $content .= "</script>\n";
        $content .= "<script>$(document).ready(function() {\n";
        $content .= "table = $('#data').DataTable( {\n";
        // The data are coming from REST
        $content .= "  'ajax': {\n";
        $content .= "    'url': '{baseurlresource}rest/records/$zoneURL/" .
                "$viewnameURL?" .
                "display[]=id&display[]=source&display[]=class&display[]=rr&" .
                "display[]=addvalues&display[]=target&display[]=comment&" .
                "display[]=opendate&display[]=closedate',\n";
        // No "data" name in the JSON provided
        // The data are put in a associated array
        $content .= "    'dataSrc': ''\n";
        $content .= "  },\n";
        // Definition of the columns options
        $content .= "    'columns': [\n";
        $content .= "        { 'data': 'id',        'visible':false },\n";
        $content .= "        { 'data': 'source'                     },\n";
        $content .= "        { 'data': 'class',     'width':'80px'  },\n";
        $content .= "        { 'data': 'rr',        'width':'80px'  },\n";
        $content .= "        { 'data': 'addvalues', 'width':'110px' },\n";
        $content .= "        { 'data': 'target'                     },\n";
        $content .= "        { 'data': 'comment'                    },\n";
        $content .= "        { 'data': 'disabled',
                           render: function (data, type, row, meta)
                           {
                             if (row.disabled === false)
                               return '';
                             return '<span class=\'label label-warning\'>" .
                             _("Disabled") . "</span>';
                           } }\n";
        $content .= "    ],\n";
        // Create the table in background (REALLY quicker than in HTML directely)
        $content .= "    'deferRender': true,\n";
        // Order the columns on first load on the source column (#1)
        $content .= "    'order': [ 1, 'asc' ],\n";
        // Pass the columns types (IP-address) to column 1 and 5 (source and target)
        $content .= "    'columnDefs': [\n";
        if ($data["directZone"]) {
            $content .= "       { type: 'ip-address', targets: 1 },\n";
        } else {
            $content .= "       { type: 'ip-reverse', targets: 1 },\n";
        }
        $content .= "       { type: 'ip-address', targets: 5 },\n";
        $content .= "    ],\n";
        // Save the state in a cookie
        $content .= "    stateSave:true,\n";
        $content .= "    stateDuration: 60*60*24*30,\n";
        $content .= "    select: {\n";
        $content .= "      style: 'multi+shift',\n";
        $content .= "      info: false\n";
        $content .= "    },\n";

        /*$content .= "  'bProcessing': true,\n";
        // Present the pagination in Bootstrap
        $content .= "  'sPaginationType': 'bootstrap'\n";*/
        // Internationalisation
        if (isset($GLOBALS["domframework"]["lang"])) {
            $content .= "        language: {
                    url:'{baseurl}public/DataTables-1.10.12/js/" .
                    $GLOBALS["domframework"]["lang"] . ".json'
                  }\n";
        }
        $content .= "} );\n";

        $content .= "$('#data_wrapper').css('cursor', 'default');\n";
        $content .= "} );</script>\n";
        $content .= "<script src='{baseurl}public/js/";
        $content .= "selectDeleteRecords.js?t=" .
                filemtime("public/js/selectDeleteRecords.js")
                . "'>";
        $content .= "</script>\n";
        return array("content" => $content,
               "title" => sprintf(
                   _("Edit record for zone '%s' and view '%s'"),
                   $zone,
                   $viewname
               ));
    }

    public function updateMultiple($data)
    {
        $zone = $data["zone"];
        $zoneURL = urlencode($zone);
        $viewname = $data["viewname"];
        $viewnameURL = urlencode($viewname);
        $titles = $data["titles"];
        $zoneid = $data["zoneid"];
        $directZone = $data["directZone"];
        $readonly = $data["readonly"];

        $values = array();
        $errors = array();

        $values = (isset($data["values"])) ? $data["values"] : $values;
        if (isset($_SESSION["domdns"]["values"])) {
            $values = $_SESSION["domdns"]["values"];
            // When providing the FQDN, store just the hostname (case of button to
            // create reverse if not exists after creation of direct record)
            if (substr($values["source"], -strlen($zone)) === $zone) {
                $values["source"] = substr($values["source"], 0, -1 - strlen($zone));
            }
            unset($_SESSION["domdns"]["values"]);
        }

        if (isset($_SESSION["domdns"]["errors"])) {
            $errors = $_SESSION["domdns"]["errors"];
            unset($_SESSION["domdns"]["errors"]);
        }

        // Creation of the form based on the content of the controller to define the
        // fields and their translation
        $f = new Form();
        $fields = array();
        $field = new Formfield("zone", _("Zone"));
        $field->type = "hidden";
        $field->defaults = $zone;
        $fields[] = $field;
        unset($field);
        $field = new Formfield("viewname", _("View"));
        $field->type = "hidden";
        $field->defaults = $viewname;
        $fields[] = $field;
        unset($field);
        $field = new Formfield("start", _("Start"));
        $field->mandatory = true;
        $fields[] = $field;
        $field = new Formfield("end", _("End"));
        $field->mandatory = true;
        $fields[] = $field;
        foreach ($titles as $key => $val) {
            $field = new Formfield($key, $val);
            if ($key === "id") {
                $field->type = "hidden";
            } elseif ($key === "zoneid") {
                $field->type = "hidden";
                $field->defaults = $zoneid;
            } elseif ($key === "class") {
                $field->defaults = "IN";
                $field->type = "select";
                $field->defaults = array("IN" => "Internet (IN)", "CH" => "Chaos (CH)",
                                  "HS" => "Hesiod (HS)");
            } elseif ($key === "rr") {
                $field->type = "select";
                if ($directZone) {
                    $field->defaults = array("A" => _("IPv4 Address (A)"),
                                    "AAAA" => _("IPv6 Address (AAAA)"));
                } else {
                    $field->defaults = array("PTR" => _("Pointer record (PTR)"));
                }
            } elseif ($key === "ttl") {
                // TODO : get TTL from configuration
                $field->placeholder = _("3600 if not filled");
            } elseif ($key === "opendate") {
                $field->defaults = date("Y-m-d H:i");
            } elseif ($key === "source") {
                $field->type = "text";
                if ($directZone == true) {
                    $field->placeholder = _("The name of the host with %d at the right " .
                                  "place");
                } else {
                    $field->placeholder = _("Inversed suffix. Use %d at the right place");
                }
            } elseif ($key === "target") {
                $field->type = "text";
                if ($directZone == true) {
                    $field->placeholder = _("An IP address in case of 'A' or 'AAAA' " .
                                  "RR Type. Use %d at the right place");
                } else {
                    $field->placeholder = _("Fully Qualified Domain Name (FQDN), ending " .
                                  "by dot. Use %d at " .
                                  "the right place");
                }
            } else {
                $field->type = "text";
            }
            if (
                $key === "id" || $key === "zoneid" || $key === "source" ||
                $key === "class" || $key === "rr" || $key === "target" ||
                $key === "opendate"
            ) {
                $field->mandatory = true;
            }
            if ($readonly) {
                $field->readonly = true;
            }
            $fields[] = $field;
            unset($field);
        }

        if (!$readonly) {
            $field = new Formfield("submit", _("Save the record"));
            $field->defaults = _("Save the record");
            $field->type = "submit";
            $fields[] = $field;
        }

        $f->fields($fields);

        // Display the form with the defined fields and the values from the last
        // page or the default values
        foreach ($errors as $k => $v) {
            $errors[$k] = array($v[0], $v[1]);
        }

        // The result :
        // Can display the flash
        $dataflash = Flash::call();
        $content = $dataflash;

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}zone'>" . _("Zones") .
                "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}zone/$zoneURL'>" .
                "$zone</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}zone/$zoneURL/$viewnameURL'>" .
                "$viewname</a>";
        $content .= "</li>\n";
        $content .= "</ol>\n";
        $content .= $this->menuUpdate("multiple");

        $content .= $f->printHTML("post", $values, $errors);
        $content .= "<script>\n";
        $content .= "$('#form_opendate').wrap ('<div class=\"input-group\"> ');\n";
        $content .= "$('#form_opendate').after ('<span class=\"input-group-btn\">" .
                "<button class=\"btn btn-default\" type=\"button\" " .
                "id=\"btnOpen\">" . _("Open now") . "</button></span>');\n";
        $content .= "$('#btnOpen').click (function () {\n";
        // I don't use the JS to found the date, it need an external library !
        $content .= "  $('#form_opendate').val ('" . date("Y-m-d H:i") . "');\n";
        $content .= "});\n";
        $content .= "$('#form_closedate').wrap ('<div class=\"input-group\"> ');\n";
        $content .= "$('#form_closedate').after ('<span class=\"input-group-btn\">" .
                "<button class=\"btn btn-default\" type=\"button\" " .
                "id=\"btnClose\">" . _("Close now") . "</button></span>');\n";
        $content .= "$('#btnClose').click (function () {\n";
        // I don't use the JS to found the date, it need an external library !
        $content .= "  $('#form_closedate').val ('" . date("Y-m-d H:i") . "');\n";
        $content .= "});\n";
        $content .= "</script>\n";

        return array("content" => $content,
               "title" => sprintf(
                   _("Edit record for zone '%s' and view '%s'"),
                   $zone,
                   $viewname
               ));
    }

    public function update($data)
    {
        $zone = $data["zone"];
        $zoneURL = urlencode($zone);
        $viewname = $data["viewname"];
        $viewnameURL = urlencode($viewname);
        $titles = $data["titles"];
        $zoneid = $data["zoneid"];
        $directZone = $data["directZone"];
        $readonly = $data["readonly"];

        $values = array();
        $errors = array();

        $values = (isset($data["values"])) ? $data["values"] : $values;
        if (isset($_SESSION["domdns"]["values"])) {
            $values = $_SESSION["domdns"]["values"];
            // When providing the FQDN, store just the hostname (case of button to
            // create reverse if not exists after creation of direct record)
            if (substr($values["source"], -strlen($zone)) === $zone) {
                $values["source"] = substr($values["source"], 0, -1 - strlen($zone));
            }
            unset($_SESSION["domdns"]["values"]);
        }

        if (isset($_SESSION["domdns"]["errors"])) {
            $errors = $_SESSION["domdns"]["errors"];
            unset($_SESSION["domdns"]["errors"]);
        }

        // Creation of the form based on the content of the controller to define the
        // fields and their translation
        $f = new Form();
        $fields = array();
        $field = new Formfield("zone", _("Zone"));
        $field->type = "hidden";
        $field->defaults = $zone;
        $fields[] = $field;
        unset($field);
        $field = new Formfield("viewname", _("View"));
        $field->type = "hidden";
        $field->defaults = $viewname;
        $fields[] = $field;
        unset($field);
        foreach ($titles as $key => $val) {
            $field = new Formfield($key, $val);
            if ($key === "id") {
                $field->type = "hidden";
                if (isset($data["record"])) {
                    $field->defaults = $data["record"];
                }
            } elseif ($key === "zoneid") {
                $field->type = "hidden";
                $field->defaults = $zoneid;
            } elseif ($key === "class") {
                $field->defaults = "IN";
                $field->type = "select";
                $field->defaults = array("IN" => "Internet (IN)", "CH" => "Chaos (CH)",
                                  "HS" => "Hesiod (HS)");
            } elseif ($key === "rr") {
                $field->type = "select";
                if ($directZone) {
                    $field->defaults = array(
                    "A" => _("IPv4 Address (A)"),
                    "AAAA" => _("IPv6 Address (AAAA)"),
                    "CAA" => _("Certification Authority Authorization (CAA)"),
                    "CNAME" => _("Canonical Name (CNAME)"),
                    "MX" => _("Mail exchanger (MX)"),
                    "NS" => _("Name server (NS)"),
                    "SOA" => _("Source of Authority (SOA)"),
                    "SPF" => _("Sender Policy Framework (SPF)"),
                    "SRV" => _("Service record (SRV)"),
                    "SSHFP" => _("Secure Shell Finger Print (SSHFP)"),
                    "TXT" => _("Text record (TXT)"));
                } else {
                    $field->defaults = array(
                    "PTR" => _("Pointer record (PTR)"),
                    "NS" => _("Name server (NS)"),
                    "SOA" => _("Source of Authority (SOA)"),
                    "SRV" => _("Service record (SRV)"),
                    "TXT" => _("Text record (TXT)"));
                }
            } elseif ($key === "ttl") {
                // TODO : get TTL from configuration
                $field->placeholder = _("3600 if not filled");
            } elseif ($key === "opendate") {
                $field->defaults = date("Y-m-d H:i");
            } elseif ($key === "source") {
                $field->type = "text";
                if ($directZone == true) {
                    $field->placeholder = _("The name of the host");
                } else {
                    $field->placeholder = _("Inversed suffix");
                }
            } elseif ($key === "target") {
                $field->type = "text";
                if ($directZone == true) {
                    $field->placeholder = _("An IP address in case of 'A' or 'AAAA' " .
                                  "RR Type");
                } else {
                    $field->placeholder = _("Fully Qualified Domain Name (FQDN), ending " .
                                  "by dot in case of 'PTR' RR Type");
                }
            } else {
                $field->type = "text";
            }
            if (
                $key === "id" || $key === "zoneid" || $key === "source" ||
                $key === "class" || $key === "rr" || $key === "target" ||
                $key === "opendate"
            ) {
                $field->mandatory = true;
            }
            if ($readonly) {
                $field->readonly = true;
            }
            $fields[] = $field;
            unset($field);
        }

        if (!$readonly) {
            $field = new Formfield("submit", _("Save the record"));
            $field->defaults = _("Save the record");
            $field->type = "submit";
            $fields[] = $field;
        }

        $f->fields($fields);

        // Display the form with the defined fields and the values from the last
        // page or the default values
        foreach ($errors as $k => $v) {
            $errors[$k] = array($v[0], $v[1]);
        }

        // The result :
        // Can display the flash
        $dataflash = Flash::call();
        $content = $dataflash;

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}zone'>" . _("Zones") .
                "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}zone/$zoneURL'>" .
                "$zone</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}zone/$zoneURL/$viewnameURL'>" .
                "$viewname</a>";
        $content .= "</li>\n";
        $content .= "</ol>\n";
        if (!array_key_exists("id", $values)) {
            $content .= $this->menuUpdate("simple");
        }

        $content .= $f->printHTML("post", $values, $errors);
        $content .= "<script>\n";
        $content .= "$('#form_opendate').wrap ('<div class=\"input-group\"> ');\n";
        $content .= "$('#form_opendate').after ('<span class=\"input-group-btn\">" .
                "<button class=\"btn btn-default\" type=\"button\" " .
                "id=\"btnOpen\">" . _("Open now") . "</button></span>');\n";
        $content .= "$('#btnOpen').click (function () {\n";
        // I don't use the JS to found the date, it need an external library !
        $content .= "  $('#form_opendate').val ('" . date("Y-m-d H:i") . "');\n";
        $content .= "});\n";
        $content .= "$('#form_closedate').wrap ('<div class=\"input-group\"> ');\n";
        $content .= "$('#form_closedate').after ('<span class=\"input-group-btn\">" .
                "<button class=\"btn btn-default\" type=\"button\" " .
                "id=\"btnClose\">" . _("Close now") . "</button></span>');\n";
        $content .= "$('#btnClose').click (function () {\n";
        // I don't use the JS to found the date, it need an external library !
        $content .= "  $('#form_closedate').val ('" . date("Y-m-d H:i") . "');\n";
        $content .= "});\n";
        $content .= "</script>\n";

        return array("content" => $content,
               "title" => sprintf(
                   _("Edit record for zone '%s' and view '%s'"),
                   $zone,
                   $viewname
               ));
    }

    public function import($data, $variable)
    {
        // Can display the flash
        $dataflash = Flash::call();
        $content = $dataflash;

        $zone = $data["zone"];
        if ($zone === ".") {
            $zoneURL = "dot";
        } else {
            $zoneURL = urlencode($zone);
        }
        $viewname = $data["viewname"];
        if ($viewname === ".") {
            $viewnameURL = "dot";
        } else {
            $viewnameURL = urlencode($viewname);
        }

        $readonly = $data["readonly"];

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}zone'>" . _("Zones") .
                "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}zone/$zoneURL'>" .
                "$zone</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}zone/$zoneURL/$viewnameURL'>" .
                "$viewname</a>";
        $content .= "</li>\n";
        $content .= "</ol>\n";

        // Menu buttons
        if ($readonly === true) {
            $content .= "<div class='btn-group btn-sm'>\n";
            $content .= "<button id='readonly' type='button' disabled='disabled' ";
            $content .= "class='btn btn-info'>";
            $content .= _("Read-only zone") . "</button>\n";
            $content .= "</div>\n";
        } else {
            $content .= "<div class='btn-group btn-sm'>\n";
            $content .= "  <a id='uploadFile' type='button' ";
            $content .= "class='btn btn-default'>";
            $content .= _("Upload file") . "</a>\n";
            $content .= "</div>\n";
        }
        $values = array();
        $errors = array();

        if (isset($_SESSION["domdns"]["values"])) {
            $values = $_SESSION["domdns"]["values"];
            unset($_SESSION["domdns"]["values"]);
        }

        if (isset($_SESSION["domdns"]["errors"])) {
            $errors = $_SESSION["domdns"]["errors"];
            unset($_SESSION["domdns"]["errors"]);
        }
        $f = new Form();
        $fields = array();

        $field = new Formfield("zone", _("Zone"));
        $field->type = "hidden";
        $field->defaults = $zone;
        $fields[] = $field;
        unset($field);

        $field = new Formfield("viewname", _("View"));
        $field->type = "hidden";
        $field->defaults = $viewname;
        $fields[] = $field;
        unset($field);

        $field = new Formfield("import", _("Import Data"));
        $field->type = "textarea";
        $fields[] = $field;
        unset($field);

        if (!$readonly) {
            $field = new Formfield("submit", _("Save the records"));
            $field->defaults = _("Save the records");
            $field->type = "submit";
            $fields[] = $field;
        }

        $f->fields($fields);

        $content .= $f->printHTML("post", $values, $errors);
        $content .= "<script src='{baseurl}public/js/importZone.js'></script>\n";
        $content .= "<script>zone='$zone';viewname='$viewname';\n";
        $content .= "baseurl='{baseurl}'</script>\n";
        return $content;
    }

    /** The IP matrix for zone use */
    public function matrix($data)
    {
        $vals = array();
        foreach ($data["values"] as $val) {
            if ($val["source"] === "@") {
                continue;
            }
            $vals[] = $val["source"];
        }
        $vals = array_flip($vals);
        $content = "";
        $zone = $data["zone"];
        if ($zone === ".") {
            $zoneURL = "dot";
        } else {
            $zoneURL = urlencode($zone);
        }
        $viewname = $data["viewname"];
        if ($viewname === ".") {
            $viewnameURL = "dot";
        } else {
            $viewnameURL = urlencode($viewname);
        }
        if (strpos($zone, "ip6.arpa.")) {
            $ipv6 =  true;
        } else {
            $ipv6 = false;
        }

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}zone'>" . _("Zones") .
                "</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}zone/$zoneURL'>" .
                "$zone</a></li>\n";
        $content .= "  <li><a href='{baseurlresource}zone/$zoneURL/$viewnameURL'>" .
                "$viewname</a>";
        $content .= "</li>\n";
        $content .= "</ol>\n";

        $content .= "<div class='btn-group btn-sm'>\n";
        $content .= "<a href='{baseurlresource}zone/$zoneURL/$viewnameURL' ";
        $content .= "class='btn btn-default'>";
        $content .= _("Back to zone records") . "</a>\n";
        $content .= "</div>\n";
        $content .= "<h2>" . _("Usage of the zone") . "</h2>\n";
        $content .= "<table class='matrix'>\n";
        $content .= "  <tr>";
        $content .= "<th></th>";
        for ($x = 0; $x <= 255; $x = $x + 16) {
            if ($ipv6) {
                $content .= "<th colspan='16'>" . dechex($x) . "</th>";
            } else {
                $content .= "<th colspan='16'>$x</th>";
            }
        }
        $content .= "  </tr>";
        $ystart = 0;
        $ystop = 255;
        if (substr_count($zone, ".") === 5) {
            list($digit) = explode(".", $zone);
            $ystart = $digit;
            $ystop = $digit;
        }
        for ($y = $ystart; $y <= $ystop; $y++) {
            $content .= "  <tr>";
            if ($ipv6) {
                $content .= "<td>" . sprintf("%02x", $y) . "</td>";
            } else {
                $content .= "<td>$y</td>";
            }
            for ($x = 0; $x <= 255; $x++) {
                $content .= "<td ";
                if (
                    $ystart !== $ystop && array_key_exists("$x.$y", $vals) ||
                    $ystart === $ystop && array_key_exists("$x", $vals)
                ) {
                    $content .= "class='matrix-selected' ";
                }
                if ($ipv6) {
                    $content .= "title='" . sprintf("%02x%02x", $y, $x) . "'";
                } else {
                    $content .= "title='$y.$x'";
                }
                $content .= ">&nbsp;";
                $content .= "</td>\n";
            }
            $content .= "<tr>\n";
        }
        $content .= "</table>\n";
        $content .= "<p>" . sprintf(
            _("%d existing elements on %d (usage %0.1f%%)"),
            count($vals),
            ($ystop - $ystart + 1) * 256,
            100 * count($vals) / (($ystop - $ystart + 1) * 256)
        ) .
                "</p>\n";
        return $content;
    }

    private function menuUpdate($action)
    {
        if ($action !== "simple" && $action !== "multiple") {
            return "";
        }
        $d = "";
        $d .= "<ul class='nav nav-tabs'>\n";
        $d .= "  <li role='presentation'";
        if ($action === "simple") {
            $d .= " class='active'";
        }
        $d .= "><a href='add'>" . _("Simple Add") . "</a></li>\n";
        $d .= "  <li role='presentation'";
        if ($action === "multiple") {
            $d .= " class='active'";
        }
        $d .= "><a href='addmultiple'>" . _("Multiple Add") . "</a></li>\n";
        $d .= "</ul>\n";
        return $d;
    }
}
