<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Views;

use Domframework\Form;
use Domframework\Formfield;
use Views\Flash;

/** The view for UserPrefs */
class Userprefs
{
    public function read($data, $variable)
    {
        $user = $data["user"]["email"];
        $values = array();
        foreach ($data["values"] as $val) {
            if ($val["key"] === "autoactivate-DEFAULT") {
                $values["autoactivate-DEFAULT"] = $val["value"];
            }
            if ($val["key"] === "language") {
                $values["language"] = $val["value"];
            }
        }
        if (! isset($values["autoactivate-DEFAULT"])) {
            $values["autoactivate-DEFAULT"] = "1";
        }
        if (! isset($values["language"])) {
            if (isset($_SESSION["domdns"]["language"])) {
                $values["language"] = $_SESSION["domdns"]["language"];
            }
        }

        // Can display the flash
        $dataflash = Flash::call();
        $content = $dataflash;

        // The HTML code to confirm the removal of entry
        $content .= Confirm::call();

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}zone'>" . _("Zones") .
                "</a></li>\n";
        $content .= "</ol>\n";


        $content .= "<h2>" . _("Parameters") . "</h2>\n";
        $f = new Form();
        $fields = array();
        $field = new Formfield(
            "autoactivate-DEFAULT",
            _("Zone auto-activation (by default)")
        );
        $field->type = "select";
        $field->defaults = array(_("Manual"), _("Automatic"));
        $fields[] = $field;
        unset($field);

        $field = new Formfield("language", _("Language"));
        $field->type = "select";
        $field->defaults = array("en_US" => _("English (US)"),
                              "en_GB" => _("English (GB)"),
                              "fr_FR" => _("French"));
        $fields[] = $field;
        unset($field);

        $field = new Formfield("submit", _("Save the parameters"));
        $field->type = "submit";
        $fields[] = $field;
        unset($field);

        $f->fields($fields);
        $content .= $f->printHTML("post", $values);

        $content .= "<h2>" . _("Stored information") . "</h2>\n";
        $displayedPrefs = array("autoactivate" => _("Zone auto-activation"),
                             "language" => _("Language"));
        $content .= "<table class='table table-striped'>\n";
        $content .= "<tr><th>" . _("Category") . "</th>" .
                "<th>" . _("Key") . "</th>" .
                "<th>" . _("Value") . "</th><th></th></tr>\n";
        if (count($data["values"]) === 0) {
            $content .= "<tr><td colspan='3'>" . _("No data to display") . "</td></tr>\n";
        } else {
            foreach ($data["values"] as $val) {
                $category = substr($val["key"], 0, strpos($val["key"], "-"));
                if (
                    !array_key_exists($category, $displayedPrefs) &&
                    !array_key_exists($val["key"], $displayedPrefs)
                ) {
                    continue;
                }
                $content .= "<tr>";
                if ($category !== "") {
                    $content .= "<td>" . $displayedPrefs[$category] . "</td>";
                } else {
                    $content .= "<td>" . $displayedPrefs[$val["key"]] . "</td>";
                }
                $content .= "<td>" . $val["key"] . "</td>";
                $content .= "<td>" . $val["value"] . "</td>";
                $content .= "<td><a class='delete btn-xs btn btn-danger' href='" .
                    $val["key"] . "'>" . _("Delete") . "</a></td>";
                $content .= "</tr>\n";
            }
        }
        $content .= "</table>\n";
        $content .= "<script>baseurl='{baseurl}';</script>\n";

        $content .= "<script src='{baseurl}public/js/deleteUserprefs.js?t=" .
                filemtime("public/js/deleteUserprefs.js") . "'>";
        $content .= "</script>\n";

        return array("content" => $content,
                  "title" => sprintf(_("User preferences for '%s'"), $user));
    }
}
