<?php

/**
 * DomDNS : a DNS manager
 * @package domdns
 * @author Dominique Fournier <dominique@fournier38.fr>
 */

namespace Views;

use Domframework\Form;
use Domframework\Formfield;
use Views\Viewerror;
use Views\Flash;

/** The view for Zones */
class Zones
{
    public function read($data)
    {
        // Can display the flash
        $dataflash = Flash::call();
        $content = $dataflash;

        // The HTML code to confirm the removal of entry
        $content .= Confirm::call();

        // Create and hide the modal needed to reload all the zones
        $content .= "<!-- reloadAllZones Modal -->\n";
        $content .= "<script>\n";
        $content .= "  msgExport='" . _("Export") . "';\n";
        $content .= "  msgDone='" . _("Done") . "';\n";
        $content .= "  msgReload='" . _("Reload DNS") . "';\n";
        $content .= "  msgUpdateZoneList='" . _("Update list of zones") . "';\n";
        $content .= "</script>\n";
        $content .= "<div id='modalReloadAllZones' class='modal fade' " .
                "tabindex='-1' ";
        $content .= "role='dialog' aria-labelledby='ReloadAllZones' " .
                "aria-hidden='true'>\n";
        $content .= "  <div class='modal-dialog'>\n";
        $content .= "    <div class='modal-content'>\n";
        $content .= "      <div class='modal-header'>\n";
        $content .= "        <h3 class='modal-title'>";
        $content .= _("Status of the export and reload") . "</h3>\n";
        $content .= "      </div>\n";
        $content .= "      <div class='modal-body'>\n";
        $content .= "        <div class='progress'>\n";
        $content .= "          <div class='progress-bar progress-bar-success " .
                "progress-bar-striped active' role='progressbar' " .
                "aria-valuenow='0' aria-valuemin='0' aria-valuemax='100' " .
                "id='modalReloadAllZones_progress'>\n";
        $content .= "          <span id='modalReloadAllZones_span'>0%</span>\n";
        $content .= "          </div>\n";
        $content .= "        </div>\n";
        $content .= "        <div id='modalReloadAllZones_status'>\n";
        $content .= "        </div>\n";
        $content .= "      </div>\n";
        $content .= "      <div class='modal-footer'>\n";
        $content .= "        <button type='button' class='btn btn-default' " .
                "id='modalReloadAllZones_btn' data-dismiss='modal'>" .
                _("OK") . "</button>\n";
        $content .= "      </div>\n";
        $content .= "    </div>\n";
        $content .= "  </div>\n";
        $content .= "</div>\n";
        $content .= "<!-- End of reloadAllZones modal -->\n";

        // Parameters
        $editright = false;
        if (isset($data["editright"])) {
            $editright = $data["editright"];
        }

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}zone'>" . _("Zones") .
                "</a></li>\n";
        $content .= "</ol>\n";

        // Menu buttons
        if ($editright) {
            $content .= "<div class='btn-group btn-sm'>\n";
            $content .= "  <a id='add' class='btn btn-default' ";
            $content .= "href='{baseurlresource}zone/add'";
            $content .= ">";
            $content .= _("Add") . "</a>\n";
            $content .= "  <button id='modify' type='button' ";
            $content .= "class='disabled btn btn-default'>";
            $content .= _("Modify") . "</button>\n";
            $content .= "  <button id='delete' type='button' ";
            $content .= "class='disabled btn btn-default'>";
            $content .= _("Delete") . "</button>\n";
            $content .= "</div>\n";
        }

        if (count($data["zones"]) > 0) {
            $content .= "<div class='btn-group btn-sm'>\n";
            $content .= "  <button id='editrecords' type='button' ";
            $content .= "class='disabled btn btn-default'>";
            $content .= _("Edit Records") . "</button>\n";
            $content .= "</div>\n";
        }

        if ($editright) {
            $content .= "<script src='{baseurl}public/js/refreshAll.js?t=" .
                  filemtime("public/js/refreshAll.js") . "'>";
            $content .= "</script>\n";
            $content .= "<div class='btn-group btn-sm'>\n";
            $content .= "  <a id='exportReloadAll' class='btn btn-default'>";
            $content .= _("Export all zones and reload") . "</a>\n";
            $content .= "</div>\n";
        }

        $content .= "<div class='table-responsive'>\n";
        if (count($data["zones"]) === 0) {
            $error = new Viewerror();
            $content .= "  " . $error->html(_("No zone found"), "");
            $content .= "</div>\n";
            return array("content" => $content, "title" => _("Zones list"));
        }

        $content .= "  <table id='data' class='table table-striped' width='100%'>\n";
        // Titles
        $titles = $data["titles"];
        $content .= "    <thead><tr>";
        foreach ($titles as $key => $title) {
            if ($key === "id") {
                continue;
            }
            $content .= "<th>" . $title . "</th>";
        }
        $content .= "<th>" . _("Rights") . "</th>\n";
        $content .= "<th>" . _("Details") . "</th>";

        // Data
        $content .= "    <tbody>\n";
        foreach ($data["zones"] as $key => $vals) {
            $content .= "      <tr>";
            foreach ($vals as $key => $val) {
                if ($key === "id") {
                    continue;
                }
                if ($key === "disabled") {
                    continue;
                }
                $content .= "<td>" . $val . "</td>";
            }
            $content .= "<td>";
            if ($vals["right"] === "RO") {
                $content .= "<span class='label label-info'>" . _("RO") . "</span> ";
            }
            if ($vals["disabled"] === true) {
                $content .= "<span class='label label-warning'>" . _("Disabled") .
                    "</span>";
            }
            $content .= "</td></tr>\n";
        }

        $content .= "    </tbody>\n";
        $content .= "  </table>\n";
        $content .= "</div>\n";
        $content .= "<script>baseurl='{baseurl}';\n";
        $content .= "</script>\n";

        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "jquery.dataTables.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/jquery.dataTables.min.js") .
                "'>";
        $content .= "</script>\n";
        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "dataTables.select.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/dataTables.select.min.js") .
                "'>";
        $content .= "</script>\n";
        $content .= "<script src='{baseurl}public/DataTables-1.10.12/js/";
        $content .= "dataTables.bootstrap.min.js?t=" .
                filemtime("public/DataTables-1.10.12/js/" .
                           "dataTables.bootstrap.min.js") .
                "'>";
        $content .= "</script>\n";
        $content .= "<script src='{baseurl}public/js/selectDeleteZones.js?t=" .
                filemtime("public/js/selectDeleteZones.js") .
                "'>";
        $content .= "</script>\n";
        $content .= "<script>\n";

        // Clear all the DataTable states ! Needed to debug the states
        //$content .= "localStorage.clear();\n";

        $content .= "  table = $('#data').DataTable({\n";
        $content .= "    stateSave:true,\n";
        // Dont save the columns visibility. The user can change the viewSupport
        // configuration and the visibility should not be stored
        $content .= "    stateSaveParams: function (settings, data)\n";
        $content .= "    {\n";
        $content .= "      for (var i = data.columns.length - 1; i >= 0; i--)\n";
        $content .= "      { data.columns[i].visible = true; }\n";
        $content .= "    },\n";
        $content .= "    stateDuration: 60*60*24*30,\n";
        $content .= "    select: {\n";
        $content .= "      style: 'single',\n";
        $content .= "      info: false\n";
        $content .= "    },\n";
        if (isset($GLOBALS["domframework"]["lang"])) {
            $content .= "    language: {" .
                "url:'{baseurl}public/DataTables-1.10.12/js/" .
                $GLOBALS["domframework"]["lang"] . ".json'}\n";
        }
        $content .= "  });\n";
        // Hide the rights RW/RO
        $content .= "  table.column(7).visible (false);\n";
        if ($data["viewSupport"] === false) {
            $content .= "  table.column(1).visible (false);\n";
            $content .= "  table.column(2).visible (false);\n";
        }
        $content .= "  $('#data_wrapper').css('cursor', 'default');\n";
        $content .= "</script>\n";
        return array("content" => $content, "title" => _("Zones list"));
    }

    /** This method is used to display the edit part of zones */
    public function update($data)
    {
        // Get data from the controller
        $titles = $data["titles"];
        $zone = (isset($data["zone"])) ? $data["zone"] : null;
        $viewname = (isset($data["viewname"])) ? $data["viewname"] : null;

        $values = array();
        $errors = array();

        $values = (isset($data["values"])) ? $data["values"] : $values;
        if (isset($_SESSION["domdns"]["values"])) {
            $values = $_SESSION["domdns"]["values"];
            unset($_SESSION["domdns"]["values"]);
        }

        if (isset($_SESSION["domdns"]["errors"])) {
            $errors = $_SESSION["domdns"]["errors"];
            unset($_SESSION["domdns"]["errors"]);
        }

        // Create the form page
        if ($zone !== null && $viewname !== null) {
            $title = sprintf(
                _("Zone update for zone '%s' with view '%s'"),
                $zone,
                $viewname
            );
        } else {
            $title = _("Zone creation");
        }

        // Creation of the form based on the content of the controller to define the
        // fields and their translation
        $f = new Form();
        $fields = array();
        foreach ($titles as $key => $val) {
            $field = new Formfield($key, $val);
            if ($key === "id") {
                $field->type = "hidden";
            } elseif ($key === "viewname") {
                if ($data["viewSupport"] === false) {
                    $field->readonly = true;
                }
                $field->defaults = "default";
            } elseif ($key === "viewclients") {
                $field->help = _("The CIDRs must be separated by comma. Use 'any' for " .
                         "IPv6 or IPv4 any address.");
            } elseif ($key === "opendate") {
                $field->defaults = date("Y-m-d H:i");
            } elseif ($key === "dnssec") {
                $field->type = "select";
                $field->defaults = array(
                0 => _("No DNSSec support"),
                1 => _("DNSSec automatic support"));
            }
            if (
                $key === "id" || $key === "zone" || $key === "viewname" ||
                $key === "opendate" && $key === "dnssec"
            ) {
                $field->mandatory = true;
            }
            $fields[] = $field;
            unset($field);
        }

        $field = new Formfield("submit", _("Save the zone"));
        $field->defaults = _("Save the zone");
        $field->type = "submit";
        $fields[] = $field;
        unset($field);
        $f->fields($fields);

        // Display the form with the defined fields and the values from the last
        // page or the default values
        foreach ($errors as $k => $v) {
            $errors[$k] = array($v[0], $v[1]);
        }

        // The result :
        // Can display the flash
        $dataflash = Flash::call();
        $content = $dataflash;

        // Breadcrumbs
        $content .= "<ol class='breadcrumb'>\n";
        $content .= "  <li><a href='{baseurlresource}'>" . _("Zones") . "</a></li>\n";
        $content .= "</ol>\n";
        $content .= $f->printHTML("post", $values, $errors);
        $content .= "<script>\n";
        $content .= "$('#form_opendate').wrap ('<div class=\"input-group\"> ');\n";
        $content .= "$('#form_opendate').after ('<span class=\"input-group-btn\">" .
                "<button class=\"btn btn-default\" type=\"button\" " .
                "id=\"btnOpen\">" . _("Open now") . "</button></span>');\n";
        $content .= "$('#btnOpen').click (function () {\n";
        // I don't use the JS to found the date, it need an external library !
        $content .= "  $('#form_opendate').val ('" . date("Y-m-d H:i") . "');\n";
        $content .= "});\n";
        $content .= "$('#form_closedate').wrap ('<div class=\"input-group\"> ');\n";
        $content .= "$('#form_closedate').after ('<span class=\"input-group-btn\">" .
                "<button class=\"btn btn-default\" type=\"button\" " .
                "id=\"btnClose\">" . _("Close now") . "</button></span>');\n";
        $content .= "$('#btnClose').click (function () {\n";
        // I don't use the JS to found the date, it need an external library !
        $content .= "  $('#form_closedate').val ('" . date("Y-m-d H:i") . "');\n";
        $content .= "});\n";
        $content .= "</script>\n";
        return array("content" => $content, "title" => $title);
    }
}
