/**
 * Sorts a column containing IP addresses in typical dot notation. This can 
 * be most useful when using DataTables for a networking application, and 
 * reporting information containing IP address. Also has a matching type 
 * detection plug-in for automatic type detection.
 * Support IPv4 and IPV6 addresses
 *
 *  @name IP addresses 
 *  @summary Sort IP addresses numerically
 *  @author Dominique Fournier
 *  @author Brad Wasson (original only IPv4)
 *
 *  @example
 *    $('#example').dataTable( {
 *       columnDefs: [
 *         { type: 'ip-address', targets: 0 }
 *       ]
 *    } );
 */

jQuery.extend( jQuery.fn.dataTableExt.oSort, {
  "ip-address-pre": function ( a ) {
    var m = a.split("."), n = a.split(":"), x = "", xa = "";
    if (m.length == 4) {
      // IPV4
      for(var i = 0; i < m.length; i++) {
        var item = m[i];
        if(item.length == 1) {
          x += "00" + item;
        } else if(item.length == 2) {
          x += "0" + item;
        } else {
          x += item;
        }
      }
    }
    else if (n.length > 0)
    {
      // IPV6
      var count = 0;
      for(var i = 0; i < n.length; i++) {
        var item = n[i];
        if (i > 0)
          xa += ":"
        if(item.length == 0){
          count += 0;
        } else if(item.length == 1) {
          xa += "000" + item;
          count += 4;
        } else if(item.length == 2) {
          xa += "00" + item;
          count += 4;
        } else if(item.length == 3) {
          xa += "0" + item;
          count += 4;
        } else {
          xa += item;
          count += 4;
        }
      }
      // Padding the ::
      n = xa.split(":")
      var paddDone = 0;
      for (var i = 0; i < n.length; i++) {
        var item = n[i];
        if (item.length == 0 && paddDone == 0) {
          for (var padding = 0 ; padding < (32-count) ; padding++)
          {
            x += "0";
            paddDone = 1;
          }
        }
        else
        {
          x += item;
        }
      }
    }
    else
    {
      //console.log ("Nor IPv4 nor IPV6...")
    }
    return x;
  },

  "ip-address-asc": function ( a, b ) {
    return ((a < b) ? -1 : ((a > b) ? 1 : 0));
  },

  "ip-address-desc": function ( a, b ) {
    return ((a < b) ? 1 : ((a > b) ? -1 : 0));
  }
});
