<?php

/**
 * DomFramework - Tests
 * @package domframework
 * @author Dominique Fournier <dominique@fournier38.fr>
 * @license BSD
 */

namespace Domframework\Tests;

use Domframework\Macaddresses;

/**
 * Test the Macaddresses.php file
 */
class MacaddressesTest extends \PHPUnit_Framework_TestCase
{
    public function testIsMACAddress1()
    {
        $macaddresses = new Macaddresses();
        $res = $macaddresses->isMACAddress("");
        $this->assertSame(false, $res);
    }

    public function testIsMACAddress2()
    {
        $macaddresses = new Macaddresses();
        $res = $macaddresses->isMACAddress("INVALID");
        $this->assertSame(false, $res);
    }

    public function testIsMACAddress3()
    {
        $macaddresses = new Macaddresses();
        $res = $macaddresses->isMACAddress("de:ad:be:af:aa:bb");
        $this->assertSame(true, $res);
    }

    public function testIsMACAddress4()
    {
        $macaddresses = new Macaddresses();
        $res = $macaddresses->isMACAddress("de-ad-be-af-aa-bb");
        $this->assertSame(true, $res);
    }

    public function testIsMACAddress5()
    {
        $macaddresses = new Macaddresses();
        $res = $macaddresses->isMACAddress("0005.313B.9080");
        $this->assertSame(true, $res);
    }

    public function testIsMACAddress6()
    {
        $macaddresses = new Macaddresses();
        $res = $macaddresses->isMACAddress("0005313B9080");
        $this->assertSame(true, $res);
    }

    public function testIsMACAddress7()
    {
        $macaddresses = new Macaddresses();
        $res = $macaddresses->isMACAddress("a0005313B9080a");
        $this->assertSame(false, $res);
    }

    public function testAddSeparator1()
    {
        $res = Macaddresses::addSeparator("0005313B9080");
        $this->assertSame("00:05:31:3B:90:80", $res);
    }

    public function testAddSeparator2()
    {
        $res = Macaddresses::addSeparator("0005313B9080", "-");
        $this->assertSame("00-05-31-3B-90-80", $res);
    }

    public function testAddSeparator3()
    {
        $res = Macaddresses::addSeparator("0005313B9080", ".", 4);
        $this->assertSame("0005.313B.9080", $res);
    }

    public function testAddSeparator4()
    {
        $this->expectException();
        $res = Macaddresses::addSeparator("INVALID", ".", 4);
    }

    public function testRemoveSeparator1()
    {
        $res = Macaddresses::removeSeparator("de:ad:be:af:aa:bb");
        $this->assertSame("deadbeafaabb", $res);
    }

    public function testRemoveSeparator2()
    {
        $res = Macaddresses::removeSeparator("de-ad-be-af-aa-bb");
        $this->assertSame("deadbeafaabb", $res);
    }

    public function testRemoveSeparator3()
    {
        $res = Macaddresses::removeSeparator("dead.beaf.aabb");
        $this->assertSame("deadbeafaabb", $res);
    }

    public function testRemoveSeparator4()
    {
        $res = Macaddresses::removeSeparator("deadbeafaabb");
        $this->assertSame("deadbeafaabb", $res);
    }
}
