<?php

/**
 * DomFramework - Tests
 * @package domframework
 * @author Dominique Fournier <dominique@fournier38.fr>
 * @license BSD
 */

namespace Domframework\Tests;

use Domframework\Queuefile;

/**
 * Test the Queuefile.php file
 */
class QueuefileTest extends \PHPUnit_Framework_TestCase
{
    public function testClean()
    {
        if (file_exists("/tmp/queuefileTest/queuefileTest.json")) {
            unlink("/tmp/queuefileTest/queuefileTest.json");
        }
    }

    public function testAdd1()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->add("test1");
        $this->assertSame(true, is_object($res));
    }

    public function testCount1()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->count();
        $this->assertSame(1, $res);
    }

    public function testAdd2()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->add("test2");
        $this->assertSame(true, is_object($res));
    }

    public function testCount2()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->count();
        $this->assertSame(2, $res);
    }

    public function testGetFirst1()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->getFirst();
        $this->assertSame("test1", $res);
    }

    public function testGetLast1()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->getLast();
        $this->assertSame("test2", $res);
    }

    public function testGetRange1()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->getRange(1, 1);
        $this->assertSame(["test2"], $res);
    }

    public function testGetRange2()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->getRange(0, 2);
        $this->assertSame(["test1", "test2"], $res);
    }

    public function testGetRange3()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $this->expectException();
        $res = $queuefile->getRange(0, 3);
    }

    public function testGetAll1()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->getAll();
        $this->assertSame(["test1", "test2"], $res);
    }

  // AFTER THIS TEST THE FILE WILL BE EMPTY
    public function testGetAll2()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->clear();
        $this->assertSame(true, is_object($res));
    }

    public function testCount3()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->count();
        $this->assertSame(0, $res);
    }

    public function testGetAll3()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->getAll();
        $this->assertSame([], $res);
    }

    public function testGetFirst2()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->getFirst();
        $this->assertSame(null, $res);
    }

    public function testGetLast2()
    {
        $queuefile = new Queuefile();
        $queuefile->connect("file:///tmp/queuefileTest/queuefileTest.json");
        $res = $queuefile->getLast();
        $this->assertSame(null, $res);
    }
}
