<?php

/**
 * DomFramework - Tests
 * @package domframework
 * @author Dominique Fournier <dominique@fournier38.fr>
 * @license BSD
 */

namespace Domframework\Tests;

use Domframework\Userssql;

/**
 * Test the Userssql.php file
 */
class UserssqlTest extends \PHPUnit_Framework_TestCase
{
    public function testClean()
    {
        @unlink("/tmp/database.db");
    }

    public function testInitStorage()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->initStorage();
        $this->assertSame($res, 0);
    }

    public function testListusers1()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->listusers();
        $this->assertSame($res, []);
    }

    public function testAdduser1()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->adduser("toto@toto.com", "Toto", "Toto2");
        $this->assertSame($res, "toto@toto.com");
    }

    public function testListusers2()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->listusers();
        $this->assertSame($res, [["email" => "toto@toto.com",
                                           "firstname" => "Toto",
                                           "lastname" => "Toto2"]]);
    }

    public function testOverwritepassword1()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->overwritepassword("toto@toto.com", "PassW0rd");
        $this->assertSame($res, 1);
    }

    public function testCheckValidPassword1()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->checkValidPassword("toto@toto.com", "PassW0rd");
        $this->assertSame($res, true);
    }

    public function testCheckValidPassword2()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->checkValidPassword("toto@toto.com", "BAD PASSWD");
        $this->assertSame($res, false);
    }

    public function testChangepassword1()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->changepassword("toto@toto.com", "PassW0rd", "NEW PASS!");
        $this->assertSame($res, 1);
    }

    public function testCheckValidPassword3()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->checkValidPassword("toto@toto.com", "PassW0rd");
        $this->assertSame($res, false);
    }

    public function testCheckValidPassword4()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->checkValidPassword("toto@toto.com", "NEW PASS!");
        $this->assertSame($res, true);
    }

    public function testUpdateuser()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->updateuser(
            "toto@toto.com",
            "titi@titi.com",
            "titi",
            "titi2"
        );
        $this->assertSame($res, 1);
    }

    public function testListusers3()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->listusers();
        $this->assertSame($res, [["email" => "titi@titi.com",
                                           "firstname" => "titi",
                                           "lastname" => "titi2"]]);
    }

    public function testCheckValidPassword5()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->checkValidPassword("titi@titi.com", "NEW PASS!");
        $this->assertSame($res, true);
    }

    public function testDeluser()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->deluser("titi@titi.com");
        $this->assertSame($res, 1);
    }

    public function testListusers4()
    {
        $userssql = new Userssql("sqlite:///tmp/database.db");
        $res = $userssql->listusers();
        $this->assertSame($res, []);
    }
}
