<?php

/**
 * DomFramework - Tests
 * @package domframework
 * @author Dominique Fournier <dominique@fournier38.fr>
 * @license BSD
 */

namespace Domframework\Tests;

use Domframework\Verify;

/**
 * Test the Verify
 */
class VerifyTest extends \PHPUnit_Framework_TestCase
{
    ///////////////
    //   DATES   //
    ///////////////
    public function testIsDatetimeSQL1()
    {
        $verify = new Verify();
        $res = $verify->is_datetimeSQL("2017-04-13 22:55:17");
        $this->assertSame($res, true);
    }

    public function testIsDatetimeSQL2()
    {
        $verify = new Verify();
        $res = $verify->is_datetimeSQL("2017-13-55 22:55:17");
        $this->assertSame($res, false);
    }

    public function testStaticIsDatetimeSQL1()
    {
        $res = Verify::staticIs_datetimeSQL("2017-04-13 22:55:17");
        $this->assertSame($res, true);
    }

    public function testStaticIsDatetimeSQL2()
    {
        $res = Verify::staticIs_datetimeSQL("2017-13-55 22:55:17");
        $this->assertSame($res, false);
    }
    public function testIsDateSQL1()
    {
        $verify = new Verify();
        $res = $verify->is_dateSQL("2017-04-13");
        $this->assertSame($res, true);
    }

    public function testIsDateSQL2()
    {
        $verify = new Verify();
        $res = $verify->is_dateSQL("2017-13-55");
        $this->assertSame($res, false);
    }

    public function testStaticIsDateSQL1()
    {
        $res = Verify::staticIs_dateSQL("2017-04-13");
        $this->assertSame($res, true);
    }

    public function testStaticIsDateSQL2()
    {
        $res = Verify::staticIs_dateSQL("2017-13-55");
        $this->assertSame($res, false);
    }


  /////////////////
  //   STRINGS   //
  /////////////////
    public function testStaticIsAllowedChars1()
    {
        $res = Verify::staticIsAllowedChars("éléphant", "abcd");
        $this->assertSame($res, false);
    }

    public function testStaticIsAllowedChars2()
    {
        $res = Verify::staticIsAllowedChars("éléphant", "anhplté");
        $this->assertSame($res, true);
    }

  /////////////////
  //   NUMBERS   //
  /////////////////
    public function testStaticIsInteger1()
    {
        $res = Verify::staticIs_integer("2017-04-13 22:55:17");
        $this->assertSame($res, false);
    }

    public function testStaticIsInteger2()
    {
        $res = Verify::staticIs_integer("01234");
        $this->assertSame($res, true);
    }

    public function testStaticIsInteger3()
    {
        $res = Verify::staticIs_integer("0x1234");
        $this->assertSame($res, false);
    }

    public function testStaticIsInteger4()
    {
        $res = Verify::staticIs_integer("");
        $this->assertSame($res, false);
    }

  ////////////////
  //   EMAILS   //
  ////////////////

  /////////////
  //   URL   //
  /////////////
    public function testIsUrl1()
    {
        $verify = new Verify();
        $res = $verify->is_url("invalid");
        $this->assertsame($res, false);
    }

    public function testIsUrl2()
    {
        $verify = new Verify();
        $res = $verify->is_url("http://valid");
        $this->assertsame($res, true);
    }

    public function testStaticIsUrl1()
    {
        $res = Verify::staticIs_url("invalid");
        $this->assertsame($res, false);
    }

    public function testStaticIsUrl2()
    {
        $res = Verify::staticIs_url("http://valid");
        $this->assertsame($res, true);
    }

  ////////////////
  //   OTHERS   //
  ////////////////
    public function testIsUUID1()
    {
        $verify = new Verify();
        $res = $verify->is_UUID("ca39275f-9224-425f-ba94-efce2aa5b52c");
        $this->assertsame($res, true);
    }

    public function testIsUUID2()
    {
        $verify = new Verify();
        $res = $verify->is_UUID("zz39275f-9224-425f-ba94-efce2aa5b52c");
        $this->assertsame($res, false);
    }

    public function testIsUUID3()
    {
        $verify = new Verify();
        $res = $verify->is_UUID("2c");
        $this->assertsame($res, false);
    }

    public function testStaticisUUID1()
    {
        $res = Verify::staticis_UUID("ca39275f-9224-425f-ba94-efce2aa5b52c");
        $this->assertsame($res, true);
    }

    public function testStaticisUUID2()
    {
        $res = Verify::staticis_UUID("zz39275f-9224-425f-ba94-efce2aa5b52c");
        $this->assertsame($res, false);
    }

    public function testStaticisUUID3()
    {
        $res = Verify::staticis_UUID("2c");
        $this->assertsame($res, false);
    }
}
