<?php

/**
 * DomFramework
 * @package domframework
 * @author Dominique Fournier <dominique@fournier38.fr>
 * @license BSD
 */

namespace Domframework;

/**
 * Convert the name of colors to RGB
 */
class Color
{
    /**
     * The color list
     * From http://www.rapidtables.com/web/color/index.htm
     * @var array<string, array<int>>
     */
    public $colorList = [
    // Black
    "black"                => [0, 0, 0],
    "dimgrey"              => [105, 105, 105],
    "grey"                 => [128, 128, 128],
    "darkgrey"             => [169, 169, 169],
    "silver"               => [192, 192, 192],

    // Blue
    "aliceblue"            => [240, 248, 255],
    "lavender"             => [230, 230, 250],
    "powderblue"           => [176, 224, 230],
    "lightblue"            => [173, 216, 230],
    "lightskyblue"         => [135, 206, 250],
    "skyblue"              => [135, 206, 235],
    "deepskyblue"          => [0, 191, 255],
    "lightsteelblue"       => [176, 196, 222],
    "dodgerblue"           => [30, 144, 255],
    "cornflowerblue"       => [100, 149, 237],
    "steelblue"            => [70, 130, 180],
    "cadetblue"            => [95, 158, 160],
    "mediumslateblue"      => [123, 104, 238],
    "slateblue"            => [106, 90, 205],
    "darkslateblue"        => [72, 61, 139],
    "royalblue"            => [65, 105, 225],
    "blue"                 => [0, 0, 255],
    "mediumblue"           => [0, 0, 205],
    "darkblue"             => [0, 0, 139],
    "navy"                 => [0, 0, 128],
    "midnightblue"         => [25, 25, 112],
    "blueviolet"           => [138, 43, 226],
    "indigo"               => [75, 0, 130],

    // Brown
    "cornsilk"             => [255, 248, 220],
    "blanchedalmond"       => [255, 235, 205],
    "bisque"               => [255, 228, 196],
    "wheat"                => [245, 222, 179],
    "burlywood"            => [222, 184, 135],
    "tan"                  => [210, 180, 140],
    "rosybrown"            => [188, 143, 143],
    "sandybrown"           => [244, 164, 96],
    "goldenrod"            => [218, 165, 32],
    "peru"                 => [205, 133, 63],
    "chocolate"            => [210, 105, 30],
    "saddlebrown"          => [139, 69, 19],
    "sienna"               => [160, 82, 45],
    "brown"                => [165, 42, 42],

    // Cyan
    "lightcyan"            => [224, 255, 255],
    "cyan"                 => [0, 255, 255],
    "aqua"                 => [0, 255, 255],
    "aquamarine"           => [127, 255, 212],
    "mediumaquamarine"     => [102, 205, 170],
    "paleturquoise"        => [175, 238, 238],
    "turquoise"            => [64, 224, 208],
    "mediumturquoise"      => [72, 209, 204],
    "darkturquoise"        => [0, 206, 209],
    "lightseagreen"        => [32, 178, 170],
    "darkcyan"             => [0, 139, 139],
    "teal"                 => [0, 128, 128],

    // Gold
    "palegoldenrod"        => [238, 232, 170],
    "khaki"                => [240, 230, 140],
    "gold"                 => [255, 215, 0],
    "orange"               => [255, 165, 0],
    "darkorange"           => [255, 140, 0],
    "goldenyellow"         => [255, 223, 0],
    "metallicgold"         => [212, 175, 55],
    "oldgold"              => [207, 181, 59],
    "vegasgold"            => [197, 179, 88],
    "palegold"             => [230, 190, 138],
    "goldenbrown"          => [153, 101, 21],

    // Green
    "lawngreen"            => [124, 252, 0],
    "chartreuse"           => [127, 255, 0],
    "limegreen"            => [50, 205, 50],
    "lime"                 => [0, 255, 0],
    "forestgreen"          => [34, 139, 34],
    "green"                => [0, 128, 0],
    "darkgreen"            => [0, 100, 0],
    "greenyellow"          => [173, 255, 47],
    "yellowgreen"          => [154, 205, 50],
    "springgreen"          => [0, 255, 127],
    "mediumspringgreen"    => [0, 250, 154],
    "lightgreen"           => [144, 238, 144],
    "palegreen"            => [152, 251, 152],
    "darkseagreen"         => [143, 188, 143],
    "mediumseagreen"       => [60, 179, 113],
    "seagreen"             => [46, 139, 87],
    "olive"                => [128, 128, 0],
    "darkolivegreen"       => [85, 107, 47],
    "olivedrab"            => [107, 142, 35],

    // Grey
    "gainsboro"            => [220, 220, 220],
    "lightgray"            => [211, 211, 211],
    "lightgrey"            => [211, 211, 211],
    "darkgray"             => [169, 169, 169],
    "gray"                 => [128, 128, 128],
    "dimgray"              => [105, 105, 105],
    "lightslategray"       => [119, 136, 153],
    "lightslategrey"       => [119, 136, 153],
    "slategray"            => [112, 128, 144],
    "slategrey"            => [112, 128, 144],
    "darkslategray"        => [47, 79, 79],
    "darkslategrey"        => [47, 79, 79],

    // Maroon
    "maroon"               => [128, 0, 0],

    // Orange
    "coral"                => [255, 127, 80],
    "tomato"               => [255, 99, 71],
    "orangered"            => [255, 69, 0],

    // Pink
    "pink"                 => [255, 192, 203],
    "lightpink"            => [255, 182, 193],
    "hotpink"              => [255, 105, 180],
    "deeppink"             => [255, 20, 147],
    "palevioletred"        => [219, 112, 147],
    "mediumvioletred"      => [199, 21, 133],

    // Purple
    "thistle"              => [216, 191, 216],
    "plum"                 => [221, 160, 221],
    "violet"               => [238, 130, 238],
    "orchid"               => [218, 112, 214],
    "fuchsia"              => [255, 0, 255],
    "magenta"              => [255, 0, 255],
    "mediumorchid"         => [186, 85, 211],
    "mediumpurple"         => [147, 112, 219],
    "darkviolet"           => [148, 0, 211],
    "darkorchid"           => [153, 50, 204],
    "darkmagenta"          => [139, 0, 139],
    "purple"               => [128, 0, 128],

    // Red
    "lightsalmon"          => [255, 160, 122],
    "salmon"               => [250, 128, 114],
    "darksalmon"           => [233, 150, 122],
    "lightcoral"           => [240, 128, 128],
    "indianred"            => [205, 92, 92],
    "crimson"              => [220, 20, 60],
    "firebrick"            => [178, 34, 34],
    "red"                  => [255, 0, 0],
    "darkred"              => [139, 0, 0],

    // White
    "white"                => [255, 255, 255],
    "snow"                 => [255, 250, 250],
    "honeydew"             => [240, 255, 240],
    "mintcream"            => [245, 255, 250],
    "azure"                => [240, 255, 255],
    "ghostwhite"           => [248, 248, 255],
    "whitesmoke"           => [245, 245, 245],
    "seashell"             => [255, 245, 238],
    "beige"                => [245, 245, 220],
    "oldlace"              => [253, 245, 230],
    "floralwhite"          => [255, 250, 240],
    "ivory"                => [255, 255, 240],
    "antiquewhite"         => [250, 235, 215],
    "linen"                => [250, 240, 230],
    "lavenderblush"        => [255, 240, 245],
    "mistyrose"            => [255, 228, 225],
    "navajowhite"          => [255, 222, 173],

    // Yellow
    "lightyellow"          => [255, 255, 224],
    "lemonchiffon"         => [255, 250, 205],
    "lightgoldenrodyellow" => [250, 250, 210],
    "papayawhip"           => [255, 239, 213],
    "moccasin"             => [255, 228, 181],
    "peachpuff"            => [255, 218, 185],
    "darkkhaki"            => [189, 183, 107],
    "lightyellow1"         => [255, 255, 204],
    "lightyellow2"         => [255, 255, 153],
    "lightyellow3"         => [255, 255, 102],
    "lightyellow4"         => [255, 255, 51],
    "yellow"               => [255, 255, 0],
    "darkyellow1"          => [204, 204, 0],
    "darkyellow2"          => [153, 153, 0],
    "darkyellow3"          => [102, 102, 0],
    "darkyellow4"          => [51, 51, 0],
    ];

    /**
     * Return the list of the known colors list
     * @return array<string>
     */
    public static function colorList()
    {
        $color = new Color();
        $colorList = $color->colorList;
        return array_keys($colorList);
    }

    /**
     * Return an array with the RGB colors
     * @param string $colorInText The color in textual form
     * @return array<int>
     */
    public static function textToRGB($colorInText)
    {
        $color = new Color();
        $colorList = $color->colorList;
        if (! array_key_exists($colorInText, $colorList)) {
            throw new \Exception(sprintf(
                dgettext(
                    "domframework",
                    "Unknown color provided to graphColor::textToRGB: '%s'"
                ),
                $colorInText
            ), 500);
        }
        return $colorList[$colorInText];
    }

    /**
     * Allocate the color provided in text to the provided GD object
     * @param \GdImage $gd The GD resource to add the color
     * @param string $colorInText The color in textual form
     * @return int|false
     */
    public static function allocateFromText($gd, $colorInText)
    {
        if (! function_exists("imagecolorallocate")) {
            throw new \Exception(
                dgettext(
                    "domframework",
                    "No GD support in PHP : can't allocate color"
                ),
                500
            );
        }
        $rgb = Color::textToRGB($colorInText);
        return imagecolorallocate($gd, $rgb[0], $rgb[1], $rgb[2]);
    }
}
