<?php

/**
 * DomFramework
 * @package domframework
 * @author Dominique Fournier <dominique@fournier38.fr>
 * @license BSD
 */

namespace Domframework;

/**
 * The Y2 axis management
 */
class GraphAxisY2 extends GraphAxisVertical
{
    /**
     * Draw one value on the axis
     * @param resource $gd The resource to modify
     * @param integer $width The width of the labels on the axis
     * @param integer|float $val The value to draw
     */
    protected function drawOne($gd, $width, $val)
    {
        $axisColor = Color::allocateFromText($gd, $this->axisColor);
        if ($this->numerical) {
            // Do not allow the label to be longer than $this->max
            if (strlen($val) > $this->nbcharsLabel) {
                $itmp = rtrim(substr($val, 0, $this->nbcharsLabel), ".");
            } else {
                $itmp = $val;
            }
            // Write the labels align to left
            $bbox = imagettfbbox($this->fontsize, 0, $this->fontfile, $itmp);
            $labelwidth = abs($bbox[4] - $bbox[0]) + $this->padding;
            $labelheight = abs($bbox[5] - $bbox[1]);
            $y = $this->position($val);
            if ($y === null) {
                return;
            }
            // The color is forced to black
            imagettftext(
                $gd,
                $this->fontsize,
                0,
                $this->left + $this->padding + 3,
                $y + $labelheight / 2,
                Color::allocateFromText($gd, "black"),
                $this->fontfile,
                $itmp
            );

            // Display the separators
            imageline(
                $gd,
                $this->left,
                $y,
                $this->left + $this->padding,
                $y,
                $axisColor
            );
        } else {
            die("graphAxisY2:: drawOne NOT numerical line " . __LINE__ . "\n");
        }
    }

    /**
     * Draw the axis
     * @param resource $gd The resource to modify
     * @param integer $width The width of the labels on the axis
     */
    protected function drawAxis($gd, $width)
    {
        $axisColor = Color::allocateFromText($gd, $this->axisColor);
        imageline(
            $gd,
            $this->left,
            $this->bottom,
            $this->left,
            $this->top,
            $axisColor
        );
    }

    /**
     * Draw the grid
     * @param resource $gd The resource to modify
     * @param integer $width The width of the labels on the axis
     * @param integer|float $val The value to draw
     */
    protected function drawGrid($gd, $width, $val)
    {
        // The grid can't be graphed for Y2 axis : only the Y1 axis is allowed
        return;
    }
}
